﻿using System;
using System.Windows;
using System.Windows.Input;
using System.Collections.Generic;
using ChartDirector;

namespace CSharpWPFCharts
{
    //
    // Interaction logic for FinanceDemoWindow.xaml
    //
    public partial class FinanceDemoWindow : Window
    {
        public FinanceDemoWindow()
        {
            InitializeComponent();
        }

        //
        // A utility class for adding items to ComboBox
        //
        private class ListItem
        {
            string m_key;
            string m_value;

            public ListItem(string key, string val)
            {
                m_key = key;
                m_value = val;
            }

            public string Key
            {
                get { return m_key; }
            }

            public override string ToString()
            {
                return m_value;
            }
        }

        // The main ticker key and the compare to ticker key
        private string tickerKey;
        private string compareKey;

        class PriceData
        {
            public DateTime[] timeStamps;
            public double[] highData;
            public double[] lowData;
            public double[] openData;
            public double[] closeData;
            public double[] volData;

            // An extra field for price comparison
            public double[] compareData;
        };

        // In this example, we can use daily, weekly or monthly data depending on the time range
        PriceData dailyPrice;
        PriceData weeklyPrice;
        PriceData monthlyPrice;

        // Will set to true at the end of initialization - prevents events from firing before the
        // controls are properly initialized.
        private bool hasFinishedInitialization = false;

        /// <summary>
        /// Form Load event handler - initialize the form
        /// </summary>
        private void Window_Loaded(object sender, RoutedEventArgs e)
        {
            hasFinishedInitialization = false;

            timeRange.Items.Add(new ListItem("30", "1 month"));
            timeRange.Items.Add(new ListItem("60", "2 months"));
            timeRange.SelectedIndex = timeRange.Items.Add(new ListItem("90", "3 months"));
            timeRange.Items.Add(new ListItem("180", "6 months"));
            timeRange.Items.Add(new ListItem("360", "1 year"));
            timeRange.Items.Add(new ListItem("720", "2 years"));
            timeRange.Items.Add(new ListItem("1080", "3 years"));
            timeRange.Items.Add(new ListItem("1440", "4 years"));
            timeRange.Items.Add(new ListItem("1800", "5 years"));
            timeRange.Items.Add(new ListItem("3600", "10 years"));

            chartType.Items.Add(new ListItem("None", "None"));
            chartType.SelectedIndex = chartType.Items.Add(new ListItem("CandleStick", "CandleStick"));
            chartType.Items.Add(new ListItem("Close", "Closing Price"));
            chartType.Items.Add(new ListItem("Median", "Median Price"));
            chartType.Items.Add(new ListItem("OHLC", "OHLC"));
            chartType.Items.Add(new ListItem("TP", "Typical Price"));
            chartType.Items.Add(new ListItem("WC", "Weighted Close"));

            priceBand.Items.Add(new ListItem("None", "None"));
            priceBand.SelectedIndex = priceBand.Items.Add(new ListItem("BB", "Bollinger Band"));
            priceBand.Items.Add(new ListItem("DC", "Donchain Channel"));
            priceBand.Items.Add(new ListItem("Envelop", "Envelop (SMA 20 +/- 10%)"));

            avgType1.Items.Add(new ListItem("None", "None"));
            avgType1.SelectedIndex = avgType1.Items.Add(new ListItem("SMA", "Simple"));
            avgType1.Items.Add(new ListItem("EMA", "Exponential"));
            avgType1.Items.Add(new ListItem("TMA", "Triangular"));
            avgType1.Items.Add(new ListItem("WMA", "Weighted"));

            avgType2.Items.Add(new ListItem("None", "None"));
            avgType2.SelectedIndex = avgType2.Items.Add(new ListItem("SMA", "Simple"));
            avgType2.Items.Add(new ListItem("EMA", "Exponential"));
            avgType2.Items.Add(new ListItem("TMA", "Triangular"));
            avgType2.Items.Add(new ListItem("WMA", "Weighted"));

            ListItem[] indicators =
            {
                new ListItem("None", "None"),
                new ListItem("AccDist", "Accumulation/Distribution"),
                new ListItem("AroonOsc", "Aroon Oscillator"),
                new ListItem("Aroon", "Aroon Up/Down"),
                new ListItem("ADX", "Avg Directional Index"),
                new ListItem("ATR", "Avg True Range"),
                new ListItem("BBW", "Bollinger Band Width"),
                new ListItem("CMF", "Chaikin Money Flow"),
                new ListItem("COscillator", "Chaikin Oscillator"),
                new ListItem("CVolatility", "Chaikin Volatility"),
                new ListItem("CLV", "Close Location Value"),
                new ListItem("CCI", "Commodity Channel Index"),
                new ListItem("DPO", "Detrended Price Osc"),
                new ListItem("DCW", "Donchian Channel Width"),
                new ListItem("EMV", "Ease of Movement"),
                new ListItem("FStoch", "Fast Stochastic"),
                new ListItem("MACD", "MACD"),
                new ListItem("MDX", "Mass Index"),
                new ListItem("Momentum", "Momentum"),
                new ListItem("MFI", "Money Flow Index"),
                new ListItem("NVI", "Neg Volume Index"),
                new ListItem("OBV", "On Balance Volume"),
                new ListItem("Performance", "Performance"),
                new ListItem("PPO", "% Price Oscillator"),
                new ListItem("PVO", "% Volume Oscillator"),
                new ListItem("PVI", "Pos Volume Index"),
                new ListItem("PVT", "Price Volume Trend"),
                new ListItem("ROC", "Rate of Change"),
                new ListItem("RSI", "RSI"),
                new ListItem("SStoch", "Slow Stochastic"),
                new ListItem("StochRSI", "StochRSI"),
                new ListItem("TRIX", "TRIX"),
                new ListItem("UO", "Ultimate Oscillator"),
                new ListItem("Vol", "Volume"),
                new ListItem("WilliamR", "William's %R")
            };

            for (int i = 0; i < indicators.Length; ++i)
            {
                indicator1.Items.Add(indicators[i]);
                indicator2.Items.Add(indicators[i]);
            }

            for (int i = 0; i < indicators.Length; ++i)
            {
                if (indicators[i].Key == "RSI")
                    indicator1.SelectedIndex = i;
                else if (indicators[i].Key == "MACD")
                    indicator2.SelectedIndex = i;
            }

            // Enable mouse wheel zooming by setting the zoom ratio to 1.1 per wheel event
            WPFChartViewer1.MouseWheelZoomRatio = 1.1;

            // Initially set the mouse usage to "Pointer" mode (Drag to Scroll mode)
            pointerPB.IsChecked = true;
            WPFChartViewer1.MouseUsage = WinChartMouseUsage.ScrollOnDrag;

            // Set the ticker symbol and load the data
            tickerSymbol.Text = "ASE";
            loadData();

            // Draw the chart
            hasFinishedInitialization = true;
            drawChart(WPFChartViewer1);
        }

        //
        // Load data to draw the chart
        //
        private void loadData()
        {
            // Reload main data if ticker key has changed
            if (tickerKey != tickerSymbol.Text.Trim())
            {
                tickerKey = tickerSymbol.Text.Trim();

                // Simulator to generate realistic random OHLC values
                FinanceSimulator db = new FinanceSimulator(tickerKey, new DateTime(2010, 1, 1),
                    new DateTime(2020, 12, 31), 86400);

                // Copy daily data to the data arrays
                if (null == dailyPrice)
                    dailyPrice = new PriceData();
                dailyPrice.timeStamps = db.getTimeStamps();
                dailyPrice.highData = db.getHighData();
                dailyPrice.lowData = db.getLowData();
                dailyPrice.openData = db.getOpenData();
                dailyPrice.closeData = db.getCloseData();
                dailyPrice.volData = db.getVolData();

                // Set up the viewport to display the duration selected by the user
                WPFChartViewer1.setFullRange("x", 0, dailyPrice.timeStamps.Length - 1);
                int durationInDays;
                int.TryParse(((ListItem)timeRange.SelectedItem).Key, out durationInDays);
                WPFChartViewer1.ViewPortWidth = durationInDays / (double)dailyPrice.timeStamps.Length;
                WPFChartViewer1.ViewPortLeft = 1 - WPFChartViewer1.ViewPortWidth;
            }

            // Reload compare data if compare key has changed
            if ((compareKey != compareWith.Text.Trim()) && (dailyPrice != null))
            {
                compareKey = compareWith.Text.Trim();
                if (compareKey == "")
                    dailyPrice.compareData = null;
                else
                {
                    // Simulator to generate realistic random OHLC values
                    FinanceSimulator db2 = new FinanceSimulator(compareKey, new DateTime(2010, 1, 1),
                        new DateTime(2020, 12, 31), 86400);
                    dailyPrice.compareData = db2.getCloseData();
                }
            }

            // In this example, we will compute the weekly and monthly prices on demand. We just
            // need to clear the old data here.
            weeklyPrice = null;
            monthlyPrice = null;
        }

        //
        // Aggregate the data into weekly or monthly data depending on the aggregator
        //
        PriceData aggregateData(ArrayMath aggregator, PriceData p)
        {
            PriceData ret = new PriceData();
            ret.timeStamps = aggregator.aggregate(p.timeStamps, Chart.AggregateFirst);
            ret.highData = aggregator.aggregate(p.highData, Chart.AggregateMax);
            ret.lowData = aggregator.aggregate(p.lowData, Chart.AggregateMin);
            ret.openData = aggregator.aggregate(p.openData, Chart.AggregateFirst);
            ret.closeData = aggregator.aggregate(p.closeData, Chart.AggregateLast);
            ret.volData = aggregator.aggregate(p.volData, Chart.AggregateSum);
            ret.compareData = aggregator.aggregate(p.compareData, Chart.AggregateLast);
            return ret;
        }

        //
        // In this sample code, the chart updates when the user selection changes. You may 
        // modify the code to update the data and chart periodically for real time charts.
        //
        private void ChartConfig_Changed(object sender, EventArgs e)
        {
            if (hasFinishedInitialization)
                drawChart(WPFChartViewer1);
        }

        //
        // For the ticker symbols, the chart will update when the user enters a new symbol,
        // and then press the enter button or leave the text box.
        //

        private void tickerSymbol_LostFocus(object sender, RoutedEventArgs e)
        {
            // User leave ticker symbol text box - redraw chart if symbol has changed
            
            if (tickerSymbol.Text.Trim() == "")
                // Default Symbol
                tickerSymbol.Text = "ASE";

            if (tickerSymbol.Text.Trim() != tickerKey)
            {
                loadData();
                drawChart(WPFChartViewer1);
            }
        }

        private void tickerSymbol_KeyDown(object sender, KeyEventArgs e)
        {
            // User press enter key - same action as leaving the text box.
            if (e.Key == Key.Return)
                tickerSymbol_LostFocus(sender, e);
        }

        private void compareWith_LostFocus(object sender, RoutedEventArgs e)
        {
            // User leave compare symbol text box - redraw chart if symbol has changed
            if (compareWith.Text.Trim() != compareKey)
            {
                loadData();
                drawChart(WPFChartViewer1);
            }
        }

        private void compareWith_KeyDown(object sender, KeyEventArgs e)
        {
            // User press enter key - same action as leaving the text box.
            if (e.Key == Key.Return)
                compareWith_LostFocus(sender, e);
        }

        //
        // The time range selection changes
        //
        private void timeRange_Changed(object sender, EventArgs e)
        {
            if (hasFinishedInitialization && (null != dailyPrice))
            {
                // Update the viewport to reflect the new time range, then update the chart.
                int durationInDays;
                int.TryParse(((ListItem)timeRange.SelectedItem).Key, out durationInDays);
                WPFChartViewer1.ViewPortWidth = durationInDays / (double)dailyPrice.timeStamps.Length;
                WPFChartViewer1.ViewPortLeft = 1 - WPFChartViewer1.ViewPortWidth;
                WPFChartViewer1.updateViewPort(true, true);
            }
        }

        /// <summary>
        /// Draw the chart according to user selection and display it in the WPFChartViewer.
        /// </summary>
        /// <param name="viewer">The WPFChartViewer object to display the chart.</param>
        private void drawChart(WPFChartViewer viewer)
        {
            // Use InvariantCulture to draw the chart. This ensures the chart will look the
            // same on any computer.
            System.Threading.Thread.CurrentThread.CurrentCulture =
                      System.Globalization.CultureInfo.InvariantCulture;

            // The first moving average period selected by the user.
            int avgPeriod1;
            int.TryParse(movAvg1.Text, out avgPeriod1);

            // The second moving average period selected by the user.
            int avgPeriod2;
            int.TryParse(movAvg2.Text, out avgPeriod2);

            // We need extra leading data points in order to compute moving averages.
            int extraPoints = Math.Max(20, Math.Max(avgPeriod1, avgPeriod2));

            // After determining the extra points, we can obtain the data
            int startIndex = (int)Math.Floor(viewer.getValueAtViewPort("x", viewer.ViewPortLeft));
            int endIndex = (int)Math.Ceiling(viewer.getValueAtViewPort("x", viewer.ViewPortRight));

            // Choose either daily, weekly or monthly prices depending on the date range
            PriceData p = dailyPrice;

            // If more than 400 trading days, use weekly or monthly prices
            if (endIndex - startIndex >= 400)
            {
                if (endIndex - startIndex < 2000)
                {
                    // Between 400 and 2000 trading days, use weekly prices
                    if (weeklyPrice == null)
                    {
                        // If no weekly prices, compute them from daily prices.
                        ArrayMath a = new ArrayMath(dailyPrice.timeStamps);
                        weeklyPrice = aggregateData(a.selectStartOfWeek(), dailyPrice);
                    }
                    p = weeklyPrice;
                }
                else
                {
                    // More than 2000 trading days, use monthly prices
                    if (monthlyPrice == null)
                    {
                        // If no monthly prices, compute them from daily prices.
                        ArrayMath a = new ArrayMath(dailyPrice.timeStamps);
                        monthlyPrice = aggregateData(a.selectStartOfMonth(), dailyPrice);
                    }
                    p = monthlyPrice;
                }

                // Re-compute the index based on the weekly/monthly prices
                startIndex = (int)Math.Floor(Chart.bSearch(p.timeStamps, dailyPrice.timeStamps[startIndex]));
                endIndex = (int)Math.Ceiling(Chart.bSearch(p.timeStamps, dailyPrice.timeStamps[endIndex]));
            }

            //
            // At this stage, all data is available. We can draw the chart as according to 
            // user input.
            //

            // Add extra points before the startIndex, as moving averages and may technical indicators 
            // requires data before the first visible point. 
            extraPoints = Math.Min(extraPoints, startIndex);
            startIndex -= extraPoints;
            int duration = endIndex - startIndex + 1;

            DateTime[] vpTimeStamps = Chart.arraySlice(p.timeStamps, startIndex, duration);
            double[] vpHighData = Chart.arraySlice(p.highData, startIndex, duration);
            double[] vpLowData = Chart.arraySlice(p.lowData, startIndex, duration);
            double[] vpOpenData = Chart.arraySlice(p.openData, startIndex, duration);
            double[] vpCloseData = Chart.arraySlice(p.closeData, startIndex, duration);
            double[] vpVolData = Chart.arraySlice(p.volData, startIndex, duration);
            double[] vpCompareData = Chart.arraySlice(p.compareData, startIndex, duration);

            //
            // The chart size.
            //
            int width = 780;
            int mainHeight = 255;
            int indicatorHeight = 80;

            // Create the chart object using the selected size
            FinanceChart m = new FinanceChart(width);

            // Hide default legend box as we are using dynamic legend
            m.setLegendStyle("normal", 8, Chart.Transparent, Chart.Transparent);

            // Set the data into the chart object
            m.setData(vpTimeStamps, vpHighData, vpLowData, vpOpenData, vpCloseData, vpVolData, extraPoints);

            // Put the ticker key at the bottom left of the FinanceChart title region
            m.addPlotAreaTitle(Chart.BottomLeft, tickerSymbol.Text);

            // A copyright message at the bottom left corner the title area
            m.addPlotAreaTitle(Chart.BottomRight, "<*font=arial.ttf,size=8*>(c) Advanced Software Engineering");

            // Add the main chart
            m.addMainChart(mainHeight);

            // Set log or linear scale according to user preference
            m.setLogScale(logScale.IsChecked.GetValueOrDefault());

            // Set axis labels to show data values or percentage change to user preference
            if (percentageScale.IsChecked.GetValueOrDefault())
                m.setPercentageAxis();

            // Draw any price line the user has selected
            string mainType = ((ListItem)chartType.SelectedItem).Key;
            if (mainType == "Close")
                m.addCloseLine(0x000040);
            else if (mainType == "TP")
                m.addTypicalPrice(0x000040);
            else if (mainType == "WC")
                m.addWeightedClose(0x000040);
            else if (mainType == "Median")
                m.addMedianPrice(0x000040);

            // Add comparison line if there is data for comparison
            if ((vpCompareData != null) && (vpCompareData.Length > extraPoints))
                m.addComparison(vpCompareData, 0x0000ff, compareKey);

            // Add moving average lines.
            addMovingAvg(m, ((ListItem)avgType1.SelectedItem).Key, avgPeriod1, 0x663300);
            addMovingAvg(m, ((ListItem)avgType2.SelectedItem).Key, avgPeriod2, 0x9900ff);

            // Draw candlesticks or OHLC symbols if the user has selected them.
            if (mainType == "CandleStick")
                m.addCandleStick(0x33ff33, 0xff3333);
            else if (mainType == "OHLC")
                m.addHLOC(0x008800, 0xcc0000);

            // Add parabolic SAR if necessary
            if (parabolicSAR.IsChecked.GetValueOrDefault())
                m.addParabolicSAR(0.02, 0.02, 0.2, Chart.DiamondShape, 5, 0x008800, 0x000000);

            // Add price band/channel/envelop to the chart according to user selection
            string selectedBand = ((ListItem)priceBand.SelectedItem).Key;
            if (selectedBand == "BB")
                m.addBollingerBand(20, 2, 0x9999ff, unchecked((int)(0xc06666ff)));
            else if (selectedBand == "DC")
                m.addDonchianChannel(20, 0x9999ff, unchecked((int)(0xc06666ff)));
            else if (selectedBand == "Envelop")
                m.addEnvelop(20, 0.1, 0x9999ff, unchecked((int)(0xc06666ff)));

            // Add volume bars to the main chart if necessary
            if (volumeBars.IsChecked.GetValueOrDefault())
                m.addVolBars(indicatorHeight, 0x99ff99, 0xff9999, 0xc0c0c0);

            // Add additional indicators as according to user selection.
            addIndicator(m, ((ListItem)indicator1.SelectedItem).Key, indicatorHeight);
            addIndicator(m, ((ListItem)indicator2.SelectedItem).Key, indicatorHeight);

            // We may need to update the track line. If the mouse is moving on the chart, the track line 
            // will be updated in MouseMovePlotArea. Otherwise, we need to update the track line here.
            if (!viewer.IsInMouseMoveEvent)
            {
                trackFinance(m, (null == viewer.Chart) ?
                    ((XYChart)m.getChart(0)).getPlotArea().getRightX() : viewer.PlotAreaMouseX);
            }

            // output the chart
            viewer.Chart = m;
        }

        //
        // Add a moving average line to the FinanceChart object.
        //
        protected LineLayer addMovingAvg(FinanceChart m, string avgType, int avgPeriod, int color)
        {
            if (avgPeriod > 1)
            {
                if (avgType == "SMA")
                    return m.addSimpleMovingAvg(avgPeriod, color);
                else if (avgType == "EMA")
                    return m.addExpMovingAvg(avgPeriod, color);
                else if (avgType == "TMA")
                    return m.addTriMovingAvg(avgPeriod, color);
                else if (avgType == "WMA")
                    return m.addWeightedMovingAvg(avgPeriod, color);
            }
            return null;
        }

        //
        // Add an indicator chart to the FinanceChart object. In this demo example, the indicator
        // parameters (such as the period used to compute RSI, colors of the lines, etc.) are hard
        // coded to commonly used values. You are welcome to design a more complex user interface 
        // to allow users to set the parameters.
        //
        protected XYChart addIndicator(FinanceChart m, string indicator, int height)
        {
            if (indicator == "RSI")
                return m.addRSI(height, 14, 0x800080, 20, 0xff6666, 0x6666ff);
            else if (indicator == "StochRSI")
                return m.addStochRSI(height, 14, 0x800080, 30, 0xff6666, 0x6666ff);
            else if (indicator == "MACD")
                return m.addMACD(height, 26, 12, 9, 0xff, 0xff00ff, 0x8000);
            else if (indicator == "FStoch")
                return m.addFastStochastic(height, 14, 3, 0x6060, 0x606000);
            else if (indicator == "SStoch")
                return m.addSlowStochastic(height, 14, 3, 0x6060, 0x606000);
            else if (indicator == "ATR")
                return m.addATR(height, 14, 0x808080, 0xff);
            else if (indicator == "ADX")
                return m.addADX(height, 14, 0x8000, 0x800000, 0x80);
            else if (indicator == "DCW")
                return m.addDonchianWidth(height, 20, 0xff);
            else if (indicator == "BBW")
                return m.addBollingerWidth(height, 20, 2, 0xff);
            else if (indicator == "DPO")
                return m.addDPO(height, 20, 0xff);
            else if (indicator == "PVT")
                return m.addPVT(height, 0xff);
            else if (indicator == "Momentum")
                return m.addMomentum(height, 12, 0xff);
            else if (indicator == "Performance")
                return m.addPerformance(height, 0xff);
            else if (indicator == "ROC")
                return m.addROC(height, 12, 0xff);
            else if (indicator == "OBV")
                return m.addOBV(height, 0xff);
            else if (indicator == "AccDist")
                return m.addAccDist(height, 0xff);
            else if (indicator == "CLV")
                return m.addCLV(height, 0xff);
            else if (indicator == "WilliamR")
                return m.addWilliamR(height, 14, 0x800080, 30, 0xff6666, 0x6666ff);
            else if (indicator == "Aroon")
                return m.addAroon(height, 14, 0x339933, 0x333399);
            else if (indicator == "AroonOsc")
                return m.addAroonOsc(height, 14, 0xff);
            else if (indicator == "CCI")
                return m.addCCI(height, 20, 0x800080, 100, 0xff6666, 0x6666ff);
            else if (indicator == "EMV")
                return m.addEaseOfMovement(height, 9, 0x6060, 0x606000);
            else if (indicator == "MDX")
                return m.addMassIndex(height, 0x800080, 0xff6666, 0x6666ff);
            else if (indicator == "CVolatility")
                return m.addChaikinVolatility(height, 10, 10, 0xff);
            else if (indicator == "COscillator")
                return m.addChaikinOscillator(height, 0xff);
            else if (indicator == "CMF")
                return m.addChaikinMoneyFlow(height, 21, 0x8000);
            else if (indicator == "NVI")
                return m.addNVI(height, 255, 0xff, 0x883333);
            else if (indicator == "PVI")
                return m.addPVI(height, 255, 0xff, 0x883333);
            else if (indicator == "MFI")
                return m.addMFI(height, 14, 0x800080, 30, 0xff6666, 0x6666ff);
            else if (indicator == "PVO")
                return m.addPVO(height, 26, 12, 9, 0xff, 0xff00ff, 0x8000);
            else if (indicator == "PPO")
                return m.addPPO(height, 26, 12, 9, 0xff, 0xff00ff, 0x8000);
            else if (indicator == "UO")
                return m.addUltimateOscillator(height, 7, 14, 28, 0x800080, 20, 0xff6666, 0x6666ff);
            else if (indicator == "Vol")
                return m.addVolIndicator(height, 0x99ff99, 0xff9999, 0xc0c0c0);
            else if (indicator == "TRIX")
                return m.addTRIX(height, 12, 0xff);
            return null;
        }

        //
        // Pointer (Drag to Scroll) button event handler
        //
        private void pointerPB_Checked(object sender, RoutedEventArgs e)
        {
            WPFChartViewer1.MouseUsage = WinChartMouseUsage.ScrollOnDrag;
        }

        //
        // Zoom In button event handler
        //
        private void zoomInPB_Checked(object sender, RoutedEventArgs e)
        {
            WPFChartViewer1.MouseUsage = WinChartMouseUsage.ZoomIn;
        }

        //
        // Zoom Out button event handler
        //
        private void zoomOutPB_Checked(object sender, RoutedEventArgs e)
        {
            WPFChartViewer1.MouseUsage = WinChartMouseUsage.ZoomOut;
        }

        //
        // The viewport changed event handler. In this example, we update the other controls
        // (the scroll bar) in addition to the chart.
        //
        private void WPFChartViewer1_ViewPortChanged(object sender, WPFViewPortEventArgs e)
        {
            updateControls(WPFChartViewer1);

            // Update the chart if necessary
            if (e.NeedUpdateChart)
                drawChart(WPFChartViewer1);
        }

        //
        // Update controls when the view port changed
        //
        private void updateControls(WPFChartViewer viewer)
        {
            // In this demo, we need to update the scroll bar to reflect the view port position and
            // width of the view port.
            hScrollBar1.IsEnabled = viewer.ViewPortWidth < 1;
            hScrollBar1.LargeChange = viewer.ViewPortWidth * (hScrollBar1.Maximum - hScrollBar1.Minimum);
            hScrollBar1.SmallChange = hScrollBar1.LargeChange * 0.1;
            hScrollBar1.ViewportSize = viewer.ViewPortWidth / Math.Max(1E-10, 1 - viewer.ViewPortWidth)
                * (hScrollBar1.Maximum - hScrollBar1.Minimum);
            hScrollBar1.Value = viewer.ViewPortLeft / Math.Max(1E-10, 1 - viewer.ViewPortWidth)
                * (hScrollBar1.Maximum - hScrollBar1.Minimum) + hScrollBar1.Minimum;
        }

        //
        // The scroll bar event handler
        //
        private void hScrollBar1_ValueChanged(object sender, RoutedPropertyChangedEventArgs<double> e)
        {
            var viewer = WPFChartViewer1;

            // When the view port is changed (user drags on the chart to scroll), the scroll bar will get
            // updated. When the scroll bar changes (eg. user drags on the scroll bar), the view port will
            // get updated. This creates an infinite loop. To avoid this, the scroll bar can update the 
            // view port only if the view port is not updating the scroll bar.
            if (!viewer.IsInViewPortChangedEvent)
            {
                // Set the view port based on the scroll bar
                viewer.ViewPortLeft = (hScrollBar1.Value - hScrollBar1.Minimum)
                    / (hScrollBar1.Maximum - hScrollBar1.Minimum) * (1 - viewer.ViewPortWidth);

                // Trigger a view port changed event to update the chart
                viewer.updateViewPort(true, false);
            }
        }

        //
        // Draw track cursor when mouse is moving over plotarea
        //
        private void WPFChartViewer1_MouseMovePlotArea(object sender, MouseEventArgs e)
        {
            var viewer = sender as WPFChartViewer;
            trackFinance((MultiChart)viewer.Chart, viewer.PlotAreaMouseX);
            viewer.updateDisplay();
        }

        //
        // Draw finance chart track line with legend
        //
        private void trackFinance(MultiChart m, int mouseX)
        {
            // Clear the current dynamic layer and get the DrawArea object to draw on it.
            DrawArea d = m.initDynamicLayer();

            // It is possible for a FinanceChart to be empty, so we need to check for it.
            if (m.getChartCount() == 0)
                return;

            // Get the data x-value that is nearest to the mouse
            int xValue = (int)(((XYChart)m.getChart(0)).getNearestXValue(mouseX));

            // Iterate the XY charts (main price chart and indicator charts) in the FinanceChart
            for (int i = 0; i < m.getChartCount(); ++i)
            {
                XYChart c = (XYChart)m.getChart(i);

                // Variables to hold the legend entries
                string ohlcLegend = "";
                List<string> legendEntries = new List<string>();

                // Iterate through all layers to find the highest data point
                for (int j = 0; j < c.getLayerCount(); ++j)
                {
                    Layer layer = c.getLayerByZ(j);
                    int xIndex = layer.getXIndexOf(xValue);
                    int dataSetCount = layer.getDataSetCount();

                    // In a FinanceChart, only layers showing OHLC data can have 4 data sets
                    if (dataSetCount == 4)
                    {
                        double highValue = layer.getDataSet(0).getValue(xIndex);
                        double lowValue = layer.getDataSet(1).getValue(xIndex);
                        double openValue = layer.getDataSet(2).getValue(xIndex);
                        double closeValue = layer.getDataSet(3).getValue(xIndex);

                        if (closeValue != Chart.NoValue)
                        {
                            // Build the OHLC legend
                            ohlcLegend = "Open: " + c.formatValue(openValue, "{value|P4}") + ", High: " +
                                c.formatValue(highValue, "{value|P4}") + ", Low: " + c.formatValue(lowValue,
                                "{value|P4}") + ", Close: " + c.formatValue(closeValue, "{value|P4}");

                            // We also draw an upward or downward triangle for up and down days and the %
                            // change
                            double lastCloseValue = layer.getDataSet(3).getValue(xIndex - 1);
                            if (lastCloseValue != Chart.NoValue)
                            {
                                double change = closeValue - lastCloseValue;
                                double percent = change * 100 / closeValue;
                                string symbol = ((change >= 0) ?
                                    "<*font,color=008800*><*img=@triangle,width=8,color=008800*>" :
                                    "<*font,color=CC0000*><*img=@invertedtriangle,width=8,color=CC0000*>");

                                ohlcLegend = ohlcLegend + "  " + symbol + " " + c.formatValue(change,
                                    "{value|P4}") + " (" + c.formatValue(percent, "{value|2}") + "%)<*/font*>"
                                    ;
                            }

                            // Use a <*block*> to make sure the line does not wrap within the legend entry
                            ohlcLegend = "<*block*>" + ohlcLegend + "      <*/*>";
                        }
                    }
                    else
                    {
                        // Iterate through all the data sets in the layer
                        for (int k = 0; k < layer.getDataSetCount(); ++k)
                        {
                            ChartDirector.DataSet dataSet = layer.getDataSetByZ(k);

                            string name = dataSet.getDataName();
                            double value = dataSet.getValue(xIndex);
                            if ((!string.IsNullOrEmpty(name)) && (value != Chart.NoValue))
                            {

                                // In a FinanceChart, the data set name consists of the indicator name and its
                                // latest value. It is like "Vol: 123M" or "RSI (14): 55.34". As we are
                                // generating the values dynamically, we need to extract the indictor name
                                // out, and also the volume unit (if any).

                                // The unit character, if any, is the last character and must not be a digit.
                                string unitChar = name.Substring(name.Length - 1);
                                if (unitChar.CompareTo("0") >= 0 && unitChar.CompareTo("9") <= 0)
                                {
                                    unitChar = "";
                                }

                                // The indicator name is the part of the name up to the colon character.
                                int delimiterPosition = name.IndexOf(":");
                                if (delimiterPosition != -1)
                                {
                                    name = name.Substring(0, delimiterPosition);
                                }

                                // In a FinanceChart, if there are two data sets, it must be representing a
                                // range.
                                if (dataSetCount == 2)
                                {
                                    // We show both values in the range in a single legend entry
                                    value = layer.getDataSet(0).getValue(xIndex);
                                    double value2 = layer.getDataSet(1).getValue(xIndex);
                                    name = name + ": " + c.formatValue(Math.Min(value, value2), "{value|P3}")
                                         + " - " + c.formatValue(Math.Max(value, value2), "{value|P3}");
                                }
                                else
                                {
                                    // In a FinanceChart, only the layer for volume bars has 3 data sets for
                                    // up/down/flat days
                                    if (dataSetCount == 3)
                                    {
                                        // The actual volume is the sum of the 3 data sets.
                                        value = layer.getDataSet(0).getValue(xIndex) + layer.getDataSet(1
                                            ).getValue(xIndex) + layer.getDataSet(2).getValue(xIndex);
                                    }

                                    // Create the legend entry
                                    name = name + ": " + c.formatValue(value, "{value|P3}") + unitChar;
                                }

                                // Build the legend entry, consist of a colored square box and the name (with
                                // the data value in it).
                                legendEntries.Add("<*block*><*img=@square,width=8,edgeColor=000000,color=" +
                                    dataSet.getDataColor().ToString("x") + "*> " + name + "<*/*>");
                            }
                        }
                    }
                }

                // Get the plot area position relative to the entire FinanceChart
                PlotArea plotArea = c.getPlotArea();
                int plotAreaLeftX = plotArea.getLeftX() + c.getAbsOffsetX();
                int plotAreaTopY = plotArea.getTopY() + c.getAbsOffsetY();

                // The legend is formed by concatenating the legend entries.
                legendEntries.Reverse();
                string legendText = String.Join("      ", legendEntries);

                // Add the date and the ohlcLegend (if any) at the beginning of the legend
                legendText = "<*block,valign=top,maxWidth=" + (plotArea.getWidth() - 5) +
                    "*><*font=Arial Bold*>[" + c.xAxis().getFormattedLabel(xValue, "mmm dd, yyyy") +
                    "]<*/font*>      " + ohlcLegend + legendText;

                // Draw a vertical track line at the x-position
                d.vline(plotAreaTopY, plotAreaTopY + plotArea.getHeight(), c.getXCoor(xValue) +
                    plotAreaLeftX - plotArea.getLeftX(), d.dashLineColor(0x000000, 0x0101));

                // Display the legend on the top of the plot area
                TTFText t = d.text(legendText, "Arial", 8);
                t.draw(plotAreaLeftX + 5, plotAreaTopY + 3, 0x000000, Chart.TopLeft);
            }
        }
    }
}