<%@ Page Language="VB" Debug="true" %>
<%@ Import Namespace="ChartDirector" %>
<%@ Register TagPrefix="chart" Namespace="ChartDirector" Assembly="netchartdir" %>

<!DOCTYPE html>

<script runat="server">

'
' Create chart
'
Protected Sub createChart(viewer As WebChartViewer, chartIndex As Integer)

    ' The value to display on the meter
    Dim value As Double = 77

    ' The meter radius and angle
    Dim radius As Integer = 50
    Dim angle As Double = value * 360.0 / 100

    ' Create an AngularMeter with transparent background
    Dim m As AngularMeter = New AngularMeter(radius * 2 + 10, radius * 2 + 10, Chart.Transparent)

    ' Set the center, radius and angular range of the meter
    m.setMeter(m.getWidth() \ 2, m.getHeight() \ 2, radius, 0, 360)

    ' For circular bar meters, we do not need pointer or graduation, so we hide them.
    m.setMeterColors(Chart.Transparent, Chart.Transparent, Chart.Transparent)
    m.setCap(0, Chart.Transparent)

    '
    ' This example demonstrates several coloring styles
    '

    ' Thd default fill and blank colors
    Dim fillColor As Integer = &H6699ff
    Dim blankColor As Integer = &Heeeeee

    If chartIndex >= 4 Then
        ' Use dark background style
        m.setColors(Chart.whiteOnBlackPalette)
        blankColor = &H222222
    End If

    If chartIndex Mod 4 = 1 Then
        ' Alternative fill color
        fillColor = &Hff6600
    ElseIf chartIndex Mod 4 = 2 Then
        ' Use a smooth color scale as the fill color
        Dim smoothColorScale() As Integer = {0, &H0022ff, 15, &H0088ff, 30, &H00ff00, 55, _
            &Hffff00, 80, &Hff0000, 100, &Hff0000}
        fillColor = m.getDrawArea().angleGradientColor(m.getWidth() \ 2, m.getHeight() \ 2, 0, _
            360, radius, radius - 20, smoothColorScale)
    ElseIf chartIndex Mod 4 = 3 Then
        ' Use a step color scale as the fill color
        Dim stepColorScale() As Integer = {0, &H0044ff, 20, &H00ee00, 50, &Heeee00, 70, &Hee0000, _
            100}
        fillColor = m.getDrawArea().angleGradientColor(m.getWidth() \ 2, m.getHeight() \ 2, 0, _
            360, radius, radius - 20, stepColorScale)
    End If

    ' Draw the blank part of the circular bar
    If angle < 360 Then
        m.addRingSector(radius, radius - 20, angle, 360, blankColor)
    End If

    ' Draw the fill part of the circular bar
    If angle > 0 Then
        m.addRingSector(radius, radius - 20, 0, angle, fillColor)
    End If

    ' Add a label at the center to display the value
    m.addText(m.getWidth() \ 2, m.getHeight() \ 2, m.formatValue(value, "{value}"), "Arial", 25, _
        Chart.TextColor, Chart.Center).setMargin(0)

    ' Output the chart
    viewer.Image = m.makeWebImage(Chart.SVG)

End Sub

'
' Page Load event handler
'
Protected Sub Page_Load(ByVal sender As System.Object, ByVal e As System.EventArgs)

    createChart(WebChartViewer0, 0)
    createChart(WebChartViewer1, 1)
    createChart(WebChartViewer2, 2)
    createChart(WebChartViewer3, 3)
    createChart(WebChartViewer4, 4)
    createChart(WebChartViewer5, 5)
    createChart(WebChartViewer6, 6)
    createChart(WebChartViewer7, 7)

End Sub

</script>

<html>
<head>
    <title>Circular Bar Meters</title>
    <script type="text/javascript" src="cdjcv.js"></script>
</head>
<body style="margin:5px 0px 0px 5px">
    <div style="font:bold 18pt verdana">
        Circular Bar Meters
    </div>
    <hr style="border:solid 1px #000080; background:#000080" />
    <div style="font:10pt verdana; margin-bottom:1.5em">
        <a href='viewsource.aspx?file=<%=Request("SCRIPT_NAME")%>'>View Source Code</a>
    </div>
    <chart:WebChartViewer id="WebChartViewer0" runat="server" />
    <chart:WebChartViewer id="WebChartViewer1" runat="server" />
    <chart:WebChartViewer id="WebChartViewer2" runat="server" />
    <chart:WebChartViewer id="WebChartViewer3" runat="server" />
    <chart:WebChartViewer id="WebChartViewer4" runat="server" />
    <chart:WebChartViewer id="WebChartViewer5" runat="server" />
    <chart:WebChartViewer id="WebChartViewer6" runat="server" />
    <chart:WebChartViewer id="WebChartViewer7" runat="server" />
</body>
</html>

