<%@ Page Language="VB" Debug="true" %>
<%@ Import Namespace="ChartDirector" %>
<%@ Register TagPrefix="chart" Namespace="ChartDirector" Assembly="netchartdir" %>

<!DOCTYPE html>

<script runat="server">

'
' Create chart
'
Protected Sub createChart(viewer As WebChartViewer, chartIndex As Integer)

    ' The value to display on the meter
    Dim value As Double = 85

    ' The meter radius and angle
    Dim radius As Integer = 50
    Dim angle As Double = value * 360.0 / 100

    ' Create an AngularMeter with transparent background
    Dim m As AngularMeter = New AngularMeter(radius * 2 + 10, radius * 2 + 10, Chart.Transparent)

    ' Set the center, radius and angular range of the meter
    m.setMeter(m.getWidth() \ 2, m.getHeight() \ 2, radius, 0, 360)

    ' For circular bar meters, we do not need pointer or graduation, so we hide them.
    m.setMeterColors(Chart.Transparent, Chart.Transparent, Chart.Transparent)
    m.setCap(0, Chart.Transparent)

    ' In this example, the circular bar has 20 segments
    Dim segmentCount As Integer = 20

    ' The angular step
    Dim angleStep As Double = 360.0 / segmentCount

    ' The gap between segments is 4.5 degrees
    Dim angleGap As Double = 4.5

    '
    ' This example demonstrates several coloring styles
    '

    ' Thd default fill and blank colors
    Dim fillColor As Integer = &H336699
    Dim blankColor As Integer = &Heeeeee

    If chartIndex >= 4 Then
        ' Use dark background style
        m.setColors(Chart.whiteOnBlackPalette)
        fillColor = &H6699ff
        blankColor = &H222222
    End If

    If chartIndex Mod 4 = 1 Then
        ' Alternative fill color
        fillColor = &H00ee33
    ElseIf chartIndex Mod 4 = 2 Then
        ' Use a smooth color scale as the fill color
        Dim smoothColorScale() As Integer = {0, &H0022ff, 15, &H0088ff, 30, &H00ff00, 55, _
            &Hffff00, 80, &Hff0000, 100, &Hff0000}
        fillColor = m.getDrawArea().angleGradientColor(m.getWidth() \ 2, m.getHeight() \ 2, 0, _
            360, radius, radius - 20, smoothColorScale)
    ElseIf chartIndex Mod 4 = 3 Then
        ' Use a step color scale as the fill color
        Dim stepColorScale() As Integer = {0, &H0044ff, 20, &H00ee00, 50, &Heeee00, 70, &Hee0000, _
            100}
        fillColor = m.getDrawArea().angleGradientColor(m.getWidth() \ 2, m.getHeight() \ 2, _
            -angleGap / 2, 360 - angleGap / 2, radius, radius - 20, stepColorScale)
    End If

    '
    ' Now we draw the segments of the bar meter
    '

    ' The segment that contains the value
    Dim currentSegment As Integer = Int(angle / angleStep)

    ' Segments after the current segment is colored with the blank color
    For i As Integer = currentSegment + 1 To segmentCount - 1
        m.addRingSector(radius, radius - 20, i * angleStep, (i + 1) * angleStep - angleGap, _
            blankColor)
    Next

    ' Segments before the current segment is colored with the fill color
    For i As Integer = 0 To currentSegment - 1
        m.addRingSector(radius, radius - 20, i * angleStep, (i + 1) * angleStep - angleGap, _
            fillColor)
    Next

    ' Segment that contains the angle will be partially filled and partially blank. We need to
    ' adjust the angle to compensated for the angle gap.
    Dim adjustedAngle As Double = currentSegment * angleStep + (angle - currentSegment * angleStep _
        ) * (1 - angleGap / angleStep)

    ' The blank part of the segment
    If (currentSegment + 1) * angleStep > angle Then
        m.addRingSector(radius, radius - 20, adjustedAngle, (currentSegment + 1) * angleStep - _
            angleGap, blankColor)
    End If

    ' The filled part of the segment.
    If angle > currentSegment * angleStep Then
        m.addRingSector(radius, radius - 20, currentSegment * angleStep, adjustedAngle, fillColor)
    End If

    ' Add a label at the center to display the value
    m.addText(m.getWidth() \ 2, m.getHeight() \ 2, m.formatValue(value, "{value}"), "Arial", 25, _
        Chart.TextColor, Chart.Center).setMargin(0)

    ' Output the chart
    viewer.Image = m.makeWebImage(Chart.SVG)

End Sub

'
' Page Load event handler
'
Protected Sub Page_Load(ByVal sender As System.Object, ByVal e As System.EventArgs)

    createChart(WebChartViewer0, 0)
    createChart(WebChartViewer1, 1)
    createChart(WebChartViewer2, 2)
    createChart(WebChartViewer3, 3)
    createChart(WebChartViewer4, 4)
    createChart(WebChartViewer5, 5)
    createChart(WebChartViewer6, 6)
    createChart(WebChartViewer7, 7)

End Sub

</script>

<html>
<head>
    <title>Circular Bar Meters (2)</title>
    <script type="text/javascript" src="cdjcv.js"></script>
</head>
<body style="margin:5px 0px 0px 5px">
    <div style="font:bold 18pt verdana">
        Circular Bar Meters (2)
    </div>
    <hr style="border:solid 1px #000080; background:#000080" />
    <div style="font:10pt verdana; margin-bottom:1.5em">
        <a href='viewsource.aspx?file=<%=Request("SCRIPT_NAME")%>'>View Source Code</a>
    </div>
    <chart:WebChartViewer id="WebChartViewer0" runat="server" />
    <chart:WebChartViewer id="WebChartViewer1" runat="server" />
    <chart:WebChartViewer id="WebChartViewer2" runat="server" />
    <chart:WebChartViewer id="WebChartViewer3" runat="server" />
    <chart:WebChartViewer id="WebChartViewer4" runat="server" />
    <chart:WebChartViewer id="WebChartViewer5" runat="server" />
    <chart:WebChartViewer id="WebChartViewer6" runat="server" />
    <chart:WebChartViewer id="WebChartViewer7" runat="server" />
</body>
</html>

