<%@ Page Language="VB" Debug="true" %>
<%@ Import Namespace="ChartDirector" %>
<%@ Register TagPrefix="chart" Namespace="ChartDirector" Assembly="netchartdir" %>

<!DOCTYPE html>

<script runat="server">

'
' Page Load event handler
'
Protected Sub Page_Load(ByVal sender As System.Object, ByVal e As System.EventArgs)

    ' The x-axis and y-axis labels
    Dim xLabels() As String = {"A", "B", "C", "D", "E", "F", "G", "H", "I", "J"}
    Dim yLabels() As String = {"0", "1", "2", "3", "4", "5", "6", "7", "8", "9"}

    ' Random data for the 10 x 10 cells
    Dim rand As RanSeries = New RanSeries(2)
    Dim zData() As Double = rand.get2DSeries(UBound(xLabels) + 1, UBound(yLabels) + 1, 0, 100)

    ' We set the middle 5 x 5 cells to NoValue to remove them from the chart
    For x As Integer = 3 To 6
        For y As Integer = 3 To 6
            zData(y * (UBound(xLabels) + 1) + x) = Chart.NoValue
        Next
    Next

    ' Create an XYChart object of size 480 x 540 pixels.
    Dim c As XYChart = New XYChart(480, 540)

    ' Set the plotarea at (50, 40) and of size 400 x 400 pixels. Set the background, border, and
    ' grid lines to transparent.
    Dim p As PlotArea = c.setPlotArea(50, 40, 400, 400, -1, -1, Chart.Transparent, _
        Chart.Transparent)

    ' Create a discrete heat map with 10 x 10 cells
    Dim layer As DiscreteHeatMapLayer = c.addDiscreteHeatMapLayer(zData, UBound(xLabels) + 1)

    ' Set the x-axis labels. Use 8pt Arial Bold font. Set axis stem to transparent, so only the
    ' labels are visible. Set 0.5 offset to position the labels in between the grid lines. Position
    ' the x-axis at the top of the chart.
    c.xAxis().setLabels(xLabels)
    c.xAxis().setLabelStyle("Arial Bold", 8)
    c.xAxis().setColors(Chart.Transparent, Chart.TextColor)
    c.xAxis().setLabelOffset(0.5)
    c.xAxis().setTitle("X axis title placeholder", "Arial Bold", 12)
    c.setXAxisOnTop()

    ' Set the y-axis labels. Use 8pt Arial Bold font. Set axis stem to transparent, so only the
    ' labels are visible. Set 0.5 offset to position the labels in between the grid lines. Reverse
    ' the y-axis so that the labels are flowing top-down instead of bottom-up.
    c.yAxis().setLabels(yLabels)
    c.yAxis().setLabelStyle("Arial Bold", 8)
    c.yAxis().setColors(Chart.Transparent, Chart.TextColor)
    c.yAxis().setLabelOffset(0.5)
    c.yAxis().setTitle("Y axis title placeholder", "Arial Bold", 12)
    c.yAxis().setReverse()

    ' Set a 3-pixel gap between cells
    layer.setCellGap(3)

    ' Use the z value as the cell label
    layer.setDataLabelFormat("{z|0}")

    ' Position the color axis 20 pixels below the plot area and of the width as the plot area. Put
    ' the labels at the bottom side of the color axis. Use 8pt Arial Bold font for the labels.
    Dim cAxis As ColorAxis = layer.setColorAxis(p.getLeftX(), p.getBottomY() + 20, Chart.TopLeft, _
        p.getWidth(), Chart.Bottom)
    cAxis.setLabelStyle("Arial Bold", 8)
    cAxis.setTitle("Color legend title placeholder", "Arial Bold", 12)

    ' Set the color stops and scale of the color axis
    Dim colorScale() As Double = {0, &H00ff00, 50, &Hffff00, 80, &Hff6600, 100, &Hff0000}
    cAxis.setColorScale(colorScale)
    cAxis.setLinearScale(0, 100, 10)

    ' Output the chart
    WebChartViewer1.Image = c.makeWebImage(Chart.SVG)

    ' Include tool tip for the chart
    WebChartViewer1.ImageMap = c.getHTMLImageMap("", "", _
        "title='<*cdml*>({xLabel}, {yLabel}) = {z|2}'")

End Sub

</script>

<html>
<head>
    <title>Heat Map Cell Labels</title>
    <script type="text/javascript" src="cdjcv.js"></script>
</head>
<body style="margin:5px 0px 0px 5px">
    <div style="font:bold 18pt verdana">
        Heat Map Cell Labels
    </div>
    <hr style="border:solid 1px #000080; background:#000080" />
    <div style="font:10pt verdana; margin-bottom:1.5em">
        <a href='viewsource.aspx?file=<%=Request("SCRIPT_NAME")%>'>View Source Code</a>
    </div>
    <chart:WebChartViewer id="WebChartViewer1" runat="server" />
</body>
</html>


