Imports ChartDirector

Public Class FrmContourZoomScroll

    ' Data points for the chart
    Dim dataX As Double()
    Dim dataY As Double()
    Dim dataZ As Double()


    ' To ensure color consistency, we need to save the first color axis And
    ' synchronize the color axis of the zoom-in charts with the this axis.
    Dim firstChart As XYChart
    Dim firstColorAxis As ColorAxis

    '
    ' Form Load Event Handler
    '
    Private Sub FrmContourZoomScroll_Load(ByVal sender As Object, ByVal e As EventArgs) _
        Handles MyBase.Load

        ' Set initial mouse usage for ChartViewer
        winChartViewer1.MouseUsage = WinChartMouseUsage.ScrollOnDrag
        winChartViewer1.ScrollDirection = WinChartDirection.HorizontalVertical

        ' By default, when the user drags a rectangle to zoom in, the x And y dimensions can zoom by
        ' different factors. KeepAspectRatio can be used to ensure the x And y dimensions are zoom by
        ' the same factor, thereby keeping the aspect ratio unchanged.
        winChartViewer1.ZoomDirection = WinChartDirection.KeepAspectRatio

        ' Enable mouse wheel zooming by setting the zoom ratio to 1.1 per wheel event
        winChartViewer1.MouseWheelZoomRatio = 1.1

        ' Configure CDML tooltip to use a semi-transparent rounded rectangle as container And 
        ' Arial Bold as font
        winChartViewer1.CDMLToolTipPrefix =
            "<*block,bgColor=60FFFFDD,roundedCorners=5,margin=5,edgeColor=000000*><*font=Arial Bold*>"

        ' Load the data
        loadData()

        ' Trigger the ViewPortChanged event to draw the chart
        winChartViewer1.updateViewPort(True, True)

        ' Configure the CViewPortControl to use transparent black for region outside the viewport,
        ' that Is, to darken the outside region.
        viewPortControl1.ViewPortExternalColor = Color.FromArgb(80, 0, 0, 0)
        viewPortControl1.ViewPortBorderColor = Color.FromArgb(80, 255, 255, 255)
        viewPortControl1.SelectionBorderColor = Color.FromArgb(80, 255, 255, 255)

        ' Draw the full thumbnail chart for the ViewPortControl
        drawFullChart(viewPortControl1, winChartViewer1)

        ' Bind the winChartViewer1 to the viewPortControl1
        viewPortControl1.Viewer = winChartViewer1

    End Sub

    '
    ' Load the data
    '
    Private Sub loadData()

        ' The x And y coordinates of the grid
        dataX = New Double() {-10, -9, -8, -7, -6, -5, -4, -3, -2, -1, 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10}
        dataY = New Double() {-10, -9, -8, -7, -6, -5, -4, -3, -2, -1, 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10}

        ' The values at the grid points. In this example, we will compute the values using the
        ' formula z = x * sin(y) + y * sin(x).
        dataZ = New Double(dataX.Length * dataY.Length - 1) {}
        For yIndex As Integer = 0 To dataY.Length - 1
            Dim y As Double = dataY(yIndex)
            For xIndex As Integer = 0 To dataX.Length - 1
                Dim x As Double = dataX(xIndex)
                dataZ(yIndex * dataX.Length + xIndex) = x * Math.Sin(y) + y * Math.Sin(x)
            Next
        Next

    End Sub

    '
    ' The ViewPortChanged event handler. This event occurs if the user scrolls or zooms in
    ' or out the chart by dragging or clicking on the chart. It can also be triggered by
    ' calling WinChartViewer.updateViewPort.
    '
    Private Sub winChartViewer1_ViewPortChanged(ByVal sender As Object,
        ByVal e As WinViewPortEventArgs) Handles winChartViewer1.ViewPortChanged

        ' In addition to updating the chart, we may also need to update other controls that
        ' changes based on the view port.
        updateControls(winChartViewer1)

        ' Update the chart if necessary
        If e.NeedUpdateChart Then
            drawChart(winChartViewer1)
        End If

    End Sub

    '
    ' Update controls when the view port changed
    '
    Private Sub updateControls(ByVal viewer As WinChartViewer)

        ' Synchronize the zoom bar value with the view port width/height
        zoomBar.Value = Math.Round(Math.Min(viewer.ViewPortWidth, viewer.ViewPortHeight) * zoomBar.Maximum)

    End Sub

    '
    ' Draw the chart.
    '
    Private Sub drawChart(ByVal viewer As WinChartViewer)

        ' Create an XYChart object 540 x 490 pixels in size
        Dim c As XYChart = New XYChart(540, 490)

        ' Set the plotarea at (50, 40) And of size 400 x 400 pixels. Use semi-transparent black
        ' (7f000000) dotted lines for both horizontal And vertical grid lines
        c.setPlotArea(50, 40, 400, 400, -1, -1, -1, c.dashLineColor(&H7F000000, Chart.DotLine), -1)

        ' Enable clipping mode to clip the part of the data that Is outside the plot area.
        c.setClipping()

        ' Add a title to the chart using 15 points Arial Bold Italic font
        c.addTitle("z = x * sin(y) + y * sin(x)      ", "Arial Bold Italic", 15)

        ' Set x-axis And y-axis title using 12 points Arial Bold Italic font
        c.xAxis().setTitle("X-Axis Title Place Holder", "Arial Bold Italic", 12)
        c.yAxis().setTitle("Y-Axis Title Place Holder", "Arial Bold Italic", 12)

        ' Set x-axis And y-axis labels to use Arial Bold font
        c.xAxis().setLabelStyle("Arial Bold")
        c.yAxis().setLabelStyle("Arial Bold")

        ' When auto-scaling, use tick spacing of 40 pixels as a guideline
        c.yAxis().setTickDensity(40)
        c.xAxis().setTickDensity(40)

        ' Add a contour layer using the given data
        Dim layer As ContourLayer = c.addContourLayer(dataX, dataY, dataZ)

        ' Move the grid lines in front of the contour layer
        c.getPlotArea().moveGridBefore(Layer)

        ' Add a color axis (the legend) in which the top left corner Is anchored at (470, 40). Set the
        ' length to 400 pixels And the labels on the right side.
        Dim cAxis As ColorAxis = layer.setColorAxis(470, 40, Chart.TopLeft, 400, Chart.Right)

        ' Add a title to the color axis using 12 points Arial Bold Italic font
        cAxis.setTitle("Color Legend Title Place Holder", "Arial Bold Italic", 12
            ).setAlignment(Chart.Right)

        ' Set color axis labels to use Arial Bold font
        cAxis.setLabelStyle("Arial Bold")

        ' In this example, we have Not explicitly configured the full x And y range. In this case, 
        ' the first time syncLinearAxisWithViewPort Is called, ChartDirector will auto-scale the axis
        ' And assume the resulting range Is the full range. In subsequent calls, ChartDirector will 
        ' set the axis range based on the view port And the full range.
        viewer.syncLinearAxisWithViewPort("x", c.xAxis())
        viewer.syncLinearAxisWithViewPort("y", c.yAxis())

        ' To ensure the color Is consistent, we must keep the color axis the same when the zooming Or
        ' scrolling the chart. To do this, we save the color axis of the first chart And synchronize 
        ' all future charts with this color axis.
        If IsNothing(firstChart) Then
            ' We need to save the first chart as well as the first color axis. Otherwise the first
            ' chart may get deleted, And this will delete the first color axis as well.
            firstChart = c
            firstColorAxis = cAxis

        Else
            cAxis.syncAxis(firstColorAxis)
        End If

        ' Display chart
        viewer.Chart = c

        ' Tooltip for the contour chart
        viewer.ImageMap = c.getHTMLImageMap("", "", "title='<*cdml*>X={x|2}<*br*>Y={y|2}<*br*>Z={z|2}'")

    End Sub

    '
    ' Draw the full thumbnail chart and display it in the given ViewPortControl
    '
    Private Sub drawFullChart(ByVal vpc As WinViewPortControl, ByVal viewer As WinChartViewer)

        ' Create an XYChart object 110 x 110 pixels in size
        Dim c As XYChart = New XYChart(110, 110)

        ' Set the plotarea to cover the entire chart. Disable grid lines by setting their colors
        ' to transparent. 
        c.setPlotArea(0, 0, c.getWidth() - 1, c.getHeight() - 1, -1, -1, -1, Chart.Transparent,
                Chart.Transparent)

        ' Add a contour layer using the given data
        Dim layer As ContourLayer = c.addContourLayer(dataX, dataY, dataZ)
        layer.setContourColor(&HCF000000)

        ' To maintain color consistency, the color axis Is synchronized to that of the first chart.
        layer.colorAxis().syncAxis(firstColorAxis)

        ' The x And y axis scales reflect the full range of the view port
        c.xAxis().setLinearScale(viewer.getValueAtViewPort("x", 0), viewer.getValueAtViewPort("x", 1),
                Chart.NoValue)
        c.yAxis().setLinearScale(viewer.getValueAtViewPort("y", 0), viewer.getValueAtViewPort("y", 1),
                Chart.NoValue)

        ' Set the chart image to the viewport control 
        vpc.Chart = c

    End Sub

    '
    ' Pointer (Drag to Scroll) button event handler
    '
    Private Sub pointerPB_CheckedChanged(ByVal sender As Object, ByVal e As EventArgs) _
        Handles pointerPB.CheckedChanged

        If sender.Checked Then
            winChartViewer1.MouseUsage = WinChartMouseUsage.ScrollOnDrag
        End If

    End Sub

    '
    ' Zoom In button event handler
    '
    Private Sub zoomInPB_CheckedChanged(ByVal sender As Object, ByVal e As EventArgs) _
        Handles zoomInPB.CheckedChanged

        If sender.Checked Then
            winChartViewer1.MouseUsage = WinChartMouseUsage.ZoomIn
        End If

    End Sub

    '
    ' Zoom Out button event handler
    '
    Private Sub zoomOutPB_CheckedChanged(ByVal sender As Object, ByVal e As EventArgs) _
        Handles zoomOutPB.CheckedChanged

        If sender.Checked Then
            winChartViewer1.MouseUsage = WinChartMouseUsage.ZoomOut
        End If

    End Sub

    '
    ' Save button event handler
    '
    Private Sub savePB_Click(ByVal sender As Object, ByVal e As EventArgs) _
        Handles savePB.Click

        ' The standard Save File dialog
        Dim fileDlg As SaveFileDialog = New SaveFileDialog()
        fileDlg.Filter = "PNG (*.png)|*.png|JPG (*.jpg)|*.jpg|GIF (*.gif)|*.gif|BMP (*.bmp)|*.bmp|" &
            "SVG (*.svg)|*.svg|PDF (*.pdf)|*.pdf"
        fileDlg.FileName = "chartdirector_demo"
        If fileDlg.ShowDialog() <> DialogResult.OK Then
            Return
        End If
        ' Save the chart
        If Not IsNothing(winChartViewer1.Chart) Then
            winChartViewer1.Chart.makeChart(fileDlg.FileName)
        End If

    End Sub

    '
    ' ValueChanged event handler for zoomBar. Zoom in around the center point and try to 
    ' maintain the aspect ratio
    '
    Private Sub zoomBar_ValueChanged(ByVal sender As Object, ByVal e As System.EventArgs) Handles zoomBar.ValueChanged

        If Not winChartViewer1.IsInViewPortChangedEvent Then
            'Remember the center point
            Dim centerX As Double = winChartViewer1.ViewPortLeft + winChartViewer1.ViewPortWidth / 2
            Dim centerY As Double = winChartViewer1.ViewPortTop + winChartViewer1.ViewPortHeight / 2

            'Aspect ratio and zoom factor
            Dim aspectRatio As Double = winChartViewer1.ViewPortWidth / winChartViewer1.ViewPortHeight
            Dim zoomTo As Double = CDbl(zoomBar.Value) / zoomBar.Maximum

            'Zoom while respecting the aspect ratio
            winChartViewer1.ViewPortWidth = zoomTo * Math.Max(1, aspectRatio)
            winChartViewer1.ViewPortHeight = zoomTo * Math.Max(1, 1 / aspectRatio)

            'Adjust ViewPortLeft and ViewPortTop to keep center point unchanged
            winChartViewer1.ViewPortLeft = centerX - winChartViewer1.ViewPortWidth / 2
            winChartViewer1.ViewPortTop = centerY - winChartViewer1.ViewPortHeight / 2

            'update the chart, but no need to update the image map yet, as the chart is still 
            'zooming and is unstable
            winChartViewer1.updateViewPort(True, False)
        End If

    End Sub

End Class