Imports ChartDirector

Public Class FrmFinanceDemo

    ' <summary>
    ' A utility class for adding items to ComboBox
    ' </summary>
    Class ListItem
        Dim m_key As String
        Dim m_value As String

        Public Sub New(ByVal k As String, ByVal v As String)
            m_key = k
            m_value = v
        End Sub

        Public ReadOnly Property Key() As String
            Get
                Return m_key
            End Get
        End Property

        Public Overrides Function ToString() As String
            Return m_value
        End Function
    End Class

    ' The main ticker key And the compare to ticker key
    Private tickerKey As String
    Private compareKey As String

    Class PriceData
        Public timeStamps() As Date
        Public highData() As Double
        Public lowData() As Double
        Public openData() As Double
        Public closeData() As Double
        Public volData() As Double

        'An extra field for price comparison
        Public compareData() As Double
    End Class

    'In this example, we can use daily, weekly Or monthly data depending on the time range
    Dim dailyPrice As PriceData
    Dim weeklyPrice As PriceData
    Dim monthlyPrice As PriceData

    ' Will set to true at the end of initialization - prevents events from firing before the
    ' controls are properly initialized.
    Private hasFinishedInitialization As Boolean

    ' <summary>
    ' Form Load event handler - initialize the form
    ' </summary>
    Private Sub FrmFinanceDemo_Load(ByVal sender As Object, ByVal e As EventArgs) Handles MyBase.Load

        timeRange.Items.Add(New ListItem("30", "1 month"))
        timeRange.Items.Add(New ListItem("60", "2 months"))
        timeRange.SelectedIndex = timeRange.Items.Add(New ListItem("90", "3 months"))
        timeRange.Items.Add(New ListItem("180", "6 months"))
        timeRange.Items.Add(New ListItem("360", "1 year"))
        timeRange.Items.Add(New ListItem("720", "2 years"))
        timeRange.Items.Add(New ListItem("1080", "3 years"))
        timeRange.Items.Add(New ListItem("1440", "4 years"))
        timeRange.Items.Add(New ListItem("1800", "5 years"))
        timeRange.Items.Add(New ListItem("3600", "10 years"))

        chartType.Items.Add(New ListItem("None", "None"))
        chartType.SelectedIndex = chartType.Items.Add(New ListItem("CandleStick", "CandleStick"))
        chartType.Items.Add(New ListItem("Close", "Closing Price"))
        chartType.Items.Add(New ListItem("Median", "Median Price"))
        chartType.Items.Add(New ListItem("OHLC", "OHLC"))
        chartType.Items.Add(New ListItem("TP", "Typical Price"))
        chartType.Items.Add(New ListItem("WC", "Weighted Close"))

        priceBand.Items.Add(New ListItem("None", "None"))
        priceBand.SelectedIndex = priceBand.Items.Add(New ListItem("BB", "Bollinger Band"))
        priceBand.Items.Add(New ListItem("DC", "Donchain Channel"))
        priceBand.Items.Add(New ListItem("Envelop", "Envelop (SMA 20 +/- 10%)"))

        avgType1.Items.Add(New ListItem("None", "None"))
        avgType1.SelectedIndex = avgType1.Items.Add(New ListItem("SMA", "Simple"))
        avgType1.Items.Add(New ListItem("EMA", "Exponential"))
        avgType1.Items.Add(New ListItem("TMA", "Triangular"))
        avgType1.Items.Add(New ListItem("WMA", "Weighted"))

        avgType2.Items.Add(New ListItem("None", "None"))
        avgType2.SelectedIndex = avgType2.Items.Add(New ListItem("SMA", "Simple"))
        avgType2.Items.Add(New ListItem("EMA", "Exponential"))
        avgType2.Items.Add(New ListItem("TMA", "Triangular"))
        avgType2.Items.Add(New ListItem("WMA", "Weighted"))

        Dim indicators() As ListItem =
        {
            New ListItem("None", "None"),
            New ListItem("AccDist", "Accumulation/Distribution"),
            New ListItem("AroonOsc", "Aroon Oscillator"),
            New ListItem("Aroon", "Aroon Up/Down"),
            New ListItem("ADX", "Avg Directional Index"),
            New ListItem("ATR", "Avg True Range"),
            New ListItem("BBW", "Bollinger Band Width"),
            New ListItem("CMF", "Chaikin Money Flow"),
            New ListItem("COscillator", "Chaikin Oscillator"),
            New ListItem("CVolatility", "Chaikin Volatility"),
            New ListItem("CLV", "Close Location Value"),
            New ListItem("CCI", "Commodity Channel Index"),
            New ListItem("DPO", "Detrended Price Osc"),
            New ListItem("DCW", "Donchian Channel Width"),
            New ListItem("EMV", "Ease of Movement"),
            New ListItem("FStoch", "Fast Stochastic"),
            New ListItem("MACD", "MACD"),
            New ListItem("MDX", "Mass Index"),
            New ListItem("Momentum", "Momentum"),
            New ListItem("MFI", "Money Flow Index"),
            New ListItem("NVI", "Neg Volume Index"),
            New ListItem("OBV", "On Balance Volume"),
            New ListItem("Performance", "Performance"),
            New ListItem("PPO", "% Price Oscillator"),
            New ListItem("PVO", "% Volume Oscillator"),
            New ListItem("PVI", "Pos Volume Index"),
            New ListItem("PVT", "Price Volume Trend"),
            New ListItem("ROC", "Rate of Change"),
            New ListItem("RSI", "RSI"),
            New ListItem("SStoch", "Slow Stochastic"),
            New ListItem("StochRSI", "StochRSI"),
            New ListItem("TRIX", "TRIX"),
            New ListItem("UO", "Ultimate Oscillator"),
            New ListItem("Vol", "Volume"),
            New ListItem("WilliamR", "William's %R")
        }

        indicator1.Items.AddRange(indicators)
        indicator2.Items.AddRange(indicators)

        For i As Integer = 0 To UBound(indicators)
            If indicators(i).Key = "RSI" Then
                indicator1.SelectedIndex = i
            ElseIf indicators(i).Key = "MACD" Then
                indicator2.SelectedIndex = i
            End If
        Next

        ' Enable mouse wheel zooming by setting the zoom ratio to 1.1 per wheel event
        winChartViewer1.MouseWheelZoomRatio = 1.1

        ' Initially set the mouse usage to "Pointer" mode (Drag to Scroll mode)
        pointerPB.Checked = True
        winChartViewer1.MouseUsage = WinChartMouseUsage.ScrollOnDrag

        ' Set the ticker symbol And load the data
        tickerSymbol.Text = "ASE"
        loadData()

        ' Draw the chart
        hasFinishedInitialization = True
        winChartViewer1.updateViewPort(True, True)

    End Sub

    '
    ' Load data to draw the chart
    '
    Private Sub loadData()

        ' Reload main data if ticker key has changed
        If tickerKey <> tickerSymbol.Text Then
            tickerKey = tickerSymbol.Text

            ' Simulator to generate realistic random OHLC values
            Dim db As FinanceSimulator = New FinanceSimulator(tickerKey, New Date(2010, 1, 1),
                New Date(2020, 12, 31), 86400)

            ' Copy daily data to the data arrays
            If IsNothing(dailyPrice) Then
                dailyPrice = New PriceData()
            End If
            dailyPrice.timeStamps = db.getTimeStamps()
            dailyPrice.highData = db.getHighData()
            dailyPrice.lowData = db.getLowData()
            dailyPrice.openData = db.getOpenData()
            dailyPrice.closeData = db.getCloseData()
            dailyPrice.volData = db.getVolData()

            ' Set up the viewport to display the duration selected by the user
            winChartViewer1.setFullRange("x", 0, dailyPrice.timeStamps.Length - 1)
            Dim durationInDays As Integer
            Integer.TryParse(timeRange.SelectedItem.Key, durationInDays)
            winChartViewer1.ViewPortWidth = durationInDays / dailyPrice.timeStamps.Length
            winChartViewer1.ViewPortLeft = 1 - winChartViewer1.ViewPortWidth
        End If

        ' Reload compare data if compare key has changed
        If compareKey <> compareWith.Text And Not IsNothing(dailyPrice) Then
            compareKey = compareWith.Text
            If compareKey = "" Then
                dailyPrice.compareData = Nothing
            Else
                ' Simulator to generate realistic random OHLC values
                Dim db2 As FinanceSimulator = New FinanceSimulator(compareKey, New Date(2010, 1, 1),
                        New Date(2020, 12, 31), 86400)
                dailyPrice.compareData = db2.getCloseData()
            End If
        End If

        ' In this example, we will compute the weekly And monthly prices on demand. We just
        ' need to clear the old data here.
        weeklyPrice = Nothing
        monthlyPrice = Nothing
    End Sub

    '
    ' Aggregate the data into weekly Or monthly data depending on the aggregator
    '
    Protected Function aggregateData(aggregator As ArrayMath, p As PriceData) As PriceData

        Dim ret As PriceData = New PriceData()
        ret.timeStamps = aggregator.aggregate(p.timeStamps, Chart.AggregateFirst)
        ret.highData = aggregator.aggregate(p.highData, Chart.AggregateMax)
        ret.lowData = aggregator.aggregate(p.lowData, Chart.AggregateMin)
        ret.openData = aggregator.aggregate(p.openData, Chart.AggregateFirst)
        ret.closeData = aggregator.aggregate(p.closeData, Chart.AggregateLast)
        ret.volData = aggregator.aggregate(p.volData, Chart.AggregateSum)
        ret.compareData = aggregator.aggregate(p.compareData, Chart.AggregateLast)
        Return ret

    End Function

    '
    ' In this sample code, the chart updates when the user selection changes. You may 
    ' modify the code to update the data And chart periodically for real time charts.
    '
    Private Sub SelectionChanged(ByVal sender As System.Object, ByVal e As System.EventArgs) _
        Handles volumeBars.CheckedChanged, parabolicSAR.CheckedChanged, logScale.CheckedChanged,
        percentageScale.CheckedChanged, chartType.SelectedIndexChanged,
        priceBand.SelectedIndexChanged, avgType1.SelectedIndexChanged, movAvg1.TextChanged,
        avgType2.SelectedIndexChanged, movAvg2.TextChanged, indicator1.SelectedIndexChanged,
        indicator2.SelectedIndexChanged

        If hasFinishedInitialization Then
            drawChart(winChartViewer1)
        End If

    End Sub

    '
    ' For the ticker symbols, the chart will update when the user enters a new symbol,
    ' and then press the enter button or leave the text box.
    '

    Private Sub tickerSymbol_Leave(ByVal sender As Object, ByVal e As System.EventArgs) _
        Handles tickerSymbol.Leave

        'User leave ticker symbol text box - redraw chart if symbol has changed

        If tickerSymbol.Text = "" Then
            ' Default Symbol
            tickerSymbol.Text = "ASE"
        End If

        If tickerSymbol.Text <> tickerKey Then
            loadData()
            drawChart(winChartViewer1)
        End If

    End Sub

    Private Sub tickerSymbol_KeyPress(ByVal sender As Object,
        ByVal e As System.Windows.Forms.KeyPressEventArgs) Handles tickerSymbol.KeyPress

        ' User press enter key - same action as leaving the text box.
        If e.KeyChar = vbCr Then
            tickerSymbol_Leave(sender, e)
        End If

    End Sub

    Private Sub compareWith_Leave(ByVal sender As Object, ByVal e As System.EventArgs) _
        Handles compareWith.Leave

        ' User leave compare symbol text box - redraw chart if symbol has changed
        If compareWith.Text <> compareKey Then
            loadData()
            drawChart(winChartViewer1)
        End If

    End Sub

    Private Sub compareWith_KeyPress(ByVal sender As Object,
        ByVal e As System.Windows.Forms.KeyPressEventArgs) Handles compareWith.KeyPress

        ' User press enter key - same action as leaving the text box.
        If e.KeyChar = vbCr Then
            compareWith_Leave(sender, e)
        End If

    End Sub

    Private Sub timeRange_SelectedIndexChanged(sender As Object, e As EventArgs) _
        Handles timeRange.SelectedIndexChanged

        If hasFinishedInitialization And Not IsNothing(dailyPrice) Then
            ' Update the viewport to reflect the New time range, then update the chart.
            Dim durationInDays As Integer
            Integer.TryParse(timeRange.SelectedItem.Key, durationInDays)
            winChartViewer1.ViewPortWidth = durationInDays / dailyPrice.timeStamps.Length
            winChartViewer1.ViewPortLeft = 1 - winChartViewer1.ViewPortWidth
            winChartViewer1.updateViewPort(True, True)
        End If

    End Sub

    ' <summary>
    ' Draw the chart according to user selection and display it in the WebChartViewer.
    ' </summary>
    ' <param name="viewer">The WebChartViewer object to display the chart.</param>
    Private Sub drawChart(ByVal viewer As WinChartViewer)

        ' Use InvariantCulture to draw the chart. This ensures the chart will look the
        ' same on any computer.
        System.Threading.Thread.CurrentThread.CurrentCulture =
            System.Globalization.CultureInfo.InvariantCulture

        ' The first moving average period selected by the user.
        Dim avgPeriod1 As Integer
        Integer.TryParse(movAvg1.Text, avgPeriod1)

        ' The second moving average period selected by the user.
        Dim avgPeriod2 As Integer
        Integer.TryParse(movAvg2.Text, avgPeriod2)

        ' We need extra leading data points in order to compute moving averages.
        Dim extraPoints As Integer = Math.Min(300, Math.Max(25, Math.Max(avgPeriod1, avgPeriod2)))

        ' After determining the extra points, we can obtain the data
        Dim startIndex As Integer = Math.Floor(viewer.getValueAtViewPort("x", viewer.ViewPortLeft))
        Dim endIndex As Integer = Math.Ceiling(viewer.getValueAtViewPort("x", viewer.ViewPortRight))

        ' Choose either daily, weekly Or monthly prices depending on the date range
        Dim p As PriceData = dailyPrice

        ' If more than 400 trading days, use weekly Or monthly prices
        If endIndex - startIndex >= 400 Then
            If endIndex - startIndex < 2000 Then
                ' Between 400 And 2000 trading days, use weekly prices
                If IsNothing(weeklyPrice) Then
                    ' If no weekly prices, compute them from daily prices.
                    Dim a As ArrayMath = New ArrayMath(dailyPrice.timeStamps)
                    weeklyPrice = aggregateData(a.selectStartOfWeek(), dailyPrice)
                End If
                p = weeklyPrice
            Else
                ' More than 2000 trading days, use monthly prices

                If IsNothing(monthlyPrice) Then
                    ' If no monthly prices, compute them from daily prices.
                    Dim a As ArrayMath = New ArrayMath(dailyPrice.timeStamps)
                    monthlyPrice = aggregateData(a.selectStartOfMonth(), dailyPrice)
                End If
                p = monthlyPrice
            End If

            ' Re-compute the index based on the weekly/monthly prices
            startIndex = Math.Floor(Chart.bSearch(p.timeStamps, dailyPrice.timeStamps(startIndex)))
            endIndex = Math.Ceiling(Chart.bSearch(p.timeStamps, dailyPrice.timeStamps(endIndex)))
        End If

        '
        ' At this stage, we have determined the price data to use. We need to obtain the part of the 
        ' arrays that are within the visible x-axis range.
        '

        ' Add extra points before the startIndex, as moving averages And may technical indicators 
        ' requires data before the first visible point. 
        extraPoints = Math.Min(extraPoints, startIndex)
        startIndex -= extraPoints
        Dim duration As Integer = endIndex - startIndex + 1

        Dim vpTimeStamps() As Date = Chart.arraySlice(p.timeStamps, startIndex, duration)
        Dim vpHighData() As Double = Chart.arraySlice(p.highData, startIndex, duration)
        Dim vpLowData() As Double = Chart.arraySlice(p.lowData, startIndex, duration)
        Dim vpOpenData() As Double = Chart.arraySlice(p.openData, startIndex, duration)
        Dim vpCloseData() As Double = Chart.arraySlice(p.closeData, startIndex, duration)
        Dim vpVolData() As Double = Chart.arraySlice(p.volData, startIndex, duration)
        Dim vpCompareData() As Double = Chart.arraySlice(p.compareData, startIndex, duration)

        '
        'The Chart size.
        '
        Dim width As Integer = 780
        Dim mainHeight As Integer = 255
        Dim indicatorHeight As Integer = 80

        ' Create the chart object using the selected size
        Dim m As FinanceChart = New FinanceChart(width)

        ' Hide default legend box as we are using dynamic legend
        m.setLegendStyle("normal", 8, Chart.Transparent, Chart.Transparent)

        ' Set the data into the chart object
        m.setData(vpTimeStamps, vpHighData, vpLowData, vpOpenData, vpCloseData, vpVolData, extraPoints)

        ' Put the ticker key at the bottom left of the FinanceChart title region
        m.addPlotAreaTitle(Chart.BottomLeft, tickerSymbol.Text)

        ' A copyright message at the bottom left corner the title area
        m.addPlotAreaTitle(Chart.BottomRight, "<*font=arial.ttf,size=8*>(c) Advanced Software Engineering")

        ' Add the main chart
        m.addMainChart(mainHeight)

        ' Set log or linear scale according to user preference
        m.setLogScale(logScale.Checked)

        ' Set axis labels to show data values or percentage change to user preference
        If percentageScale.Checked Then
            m.setPercentageAxis()
        End If

        ' Draw any price line the user has selected
        Dim mainType As String = chartType.SelectedItem.Key
        If mainType = "Close" Then
            m.addCloseLine(&H40)
        ElseIf mainType = "TP" Then
            m.addTypicalPrice(&H40)
        ElseIf mainType = "WC" Then
            m.addWeightedClose(&H40)
        ElseIf mainType = "Median" Then
            m.addMedianPrice(&H40)
        End If

        ' Add comparison line if there is data for comparison
        If (Not IsNothing(vpCompareData)) AndAlso vpCompareData.Length > extraPoints Then
            m.addComparison(vpCompareData, &HFF, compareKey)
        End If

        ' Add moving average lines.
        '
        addMovingAvg(m, avgType1.SelectedItem.Key, avgPeriod1, &H663300)
        addMovingAvg(m, avgType2.SelectedItem.Key, avgPeriod2, &H9900FF)

        ' Draw candlesticks or OHLC symbols if the user has selected them.
        If mainType = "CandleStick" Then
            m.addCandleStick(&H33FF33, &HFF3333)
        ElseIf mainType = "OHLC" Then
            m.addHLOC(&H8800, &HCC0000)
        End If

        ' Add parabolic SAR if necessary
        If parabolicSAR.Checked Then
            m.addParabolicSAR(0.02, 0.02, 0.2, Chart.DiamondShape, 5, &H8800, &H0)
        End If

        ' Add price band/channel/envelop to the chart according to user selection
        If priceBand.SelectedItem.Key = "BB" Then
            m.addBollingerBand(20, 2, &H9999FF, &HC06666FF)
        ElseIf priceBand.SelectedItem.Key = "DC" Then
            m.addDonchianChannel(20, &H9999FF, &HC06666FF)
        ElseIf priceBand.SelectedItem.Key = "Envelop" Then
            m.addEnvelop(20, 0.1, &H9999FF, &HC06666FF)
        End If

        ' Add volume bars to the main chart if necessary
        If volumeBars.Checked Then
            m.addVolBars(indicatorHeight, &H99FF99, &HFF9999, &HC0C0C0)
        End If

        ' Add additional indicators as according to user selection.
        addIndicator(m, indicator1.SelectedItem.Key, indicatorHeight)
        addIndicator(m, indicator2.SelectedItem.Key, indicatorHeight)

        ' We may need to update the track line. If the mouse Is moving on the chart, the track line 
        ' will be updated in MouseMovePlotArea. Otherwise, we need to update the track line here.
        If Not viewer.IsInMouseMoveEvent Then
            trackfinance(m, IIf(IsNothing(viewer.Chart),
                DirectCast(m.getChart(0), XYChart).getPlotArea().getRightX(), viewer.PlotAreaMouseX))
        End If

        ' output the chart
        viewer.Chart = m

    End Sub

    '
    ' Add a moving average line to the FinanceChart object.
    '
    Protected Function addMovingAvg(ByVal m As FinanceChart, ByVal avgType As String,
        ByVal avgPeriod As Integer, ByVal color As Integer) As LineLayer

        If avgPeriod > 1 Then
            If avgType = "SMA" Then
                Return m.addSimpleMovingAvg(avgPeriod, color)
            ElseIf avgType = "EMA" Then
                Return m.addExpMovingAvg(avgPeriod, color)
            ElseIf avgType = "TMA" Then
                Return m.addTriMovingAvg(avgPeriod, color)
            ElseIf avgType = "WMA" Then
                Return m.addWeightedMovingAvg(avgPeriod, color)
            End If
        End If
        Return Nothing

    End Function

    '
    ' Add an indicator chart to the FinanceChart object. In this demo example, the indicator
    ' parameters (such as the period used to compute RSI, colors of the lines, etc.) are hard
    ' coded to commonly used values. You are welcome to design a more complex user interface 
    ' to allow users to set the parameters.
    '
    Protected Function addIndicator(ByVal m As FinanceChart, ByVal indicator As String,
        ByVal height As Integer) As XYChart

        If indicator = "RSI" Then
            Return m.addRSI(height, 14, &H800080, 20, &HFF6666, &H6666FF)
        ElseIf indicator = "StochRSI" Then
            Return m.addStochRSI(height, 14, &H800080, 30, &HFF6666, &H6666FF)
        ElseIf indicator = "MACD" Then
            Return m.addMACD(height, 26, 12, 9, &HFF, &HFF00FF, &H8000)
        ElseIf indicator = "FStoch" Then
            Return m.addFastStochastic(height, 14, 3, &H6060, &H606000)
        ElseIf indicator = "SStoch" Then
            Return m.addSlowStochastic(height, 14, 3, &H6060, &H606000)
        ElseIf indicator = "ATR" Then
            Return m.addATR(height, 14, &H808080, &HFF)
        ElseIf indicator = "ADX" Then
            Return m.addADX(height, 14, &H8000, &H800000, &H80)
        ElseIf indicator = "DCW" Then
            Return m.addDonchianWidth(height, 20, &HFF)
        ElseIf indicator = "BBW" Then
            Return m.addBollingerWidth(height, 20, 2, &HFF)
        ElseIf indicator = "DPO" Then
            Return m.addDPO(height, 20, &HFF)
        ElseIf indicator = "PVT" Then
            Return m.addPVT(height, &HFF)
        ElseIf indicator = "Momentum" Then
            Return m.addMomentum(height, 12, &HFF)
        ElseIf indicator = "Performance" Then
            Return m.addPerformance(height, &HFF)
        ElseIf indicator = "ROC" Then
            Return m.addROC(height, 12, &HFF)
        ElseIf indicator = "OBV" Then
            Return m.addOBV(height, &HFF)
        ElseIf indicator = "AccDist" Then
            Return m.addAccDist(height, &HFF)
        ElseIf indicator = "CLV" Then
            Return m.addCLV(height, &HFF)
        ElseIf indicator = "WilliamR" Then
            Return m.addWilliamR(height, 14, &H800080, 30, &HFF6666, &H6666FF)
        ElseIf indicator = "Aroon" Then
            Return m.addAroon(height, 14, &H339933, &H333399)
        ElseIf indicator = "AroonOsc" Then
            Return m.addAroonOsc(height, 14, &HFF)
        ElseIf indicator = "CCI" Then
            Return m.addCCI(height, 20, &H800080, 100, &HFF6666, &H6666FF)
        ElseIf indicator = "EMV" Then
            Return m.addEaseOfMovement(height, 9, &H6060, &H606000)
        ElseIf indicator = "MDX" Then
            Return m.addMassIndex(height, &H800080, &HFF6666, &H6666FF)
        ElseIf indicator = "CVolatility" Then
            Return m.addChaikinVolatility(height, 10, 10, &HFF)
        ElseIf indicator = "COscillator" Then
            Return m.addChaikinOscillator(height, &HFF)
        ElseIf indicator = "CMF" Then
            Return m.addChaikinMoneyFlow(height, 21, &H8000)
        ElseIf indicator = "NVI" Then
            Return m.addNVI(height, 255, &HFF, &H883333)
        ElseIf indicator = "PVI" Then
            Return m.addPVI(height, 255, &HFF, &H883333)
        ElseIf indicator = "MFI" Then
            Return m.addMFI(height, 14, &H800080, 30, &HFF6666, &H6666FF)
        ElseIf indicator = "PVO" Then
            Return m.addPVO(height, 26, 12, 9, &HFF, &HFF00FF, &H8000)
        ElseIf indicator = "PPO" Then
            Return m.addPPO(height, 26, 12, 9, &HFF, &HFF00FF, &H8000)
        ElseIf indicator = "UO" Then
            Return m.addUltimateOscillator(height, 7, 14, 28, &H800080, 20, &HFF6666,
                &H6666FF)
        ElseIf indicator = "Vol" Then
            Return m.addVolIndicator(height, &H99FF99, &HFF9999, &HC0C0C0)
        ElseIf indicator = "TRIX" Then
            Return m.addTRIX(height, 12, &HFF)
        End If
        Return Nothing

    End Function

    '
    ' Pointer (Drag to Scroll) button event handler
    '
    Private Sub pointerPB_CheckedChanged(ByVal sender As Object, ByVal e As EventArgs) _
        Handles pointerPB.CheckedChanged

        If sender.Checked Then
            winChartViewer1.MouseUsage = WinChartMouseUsage.ScrollOnDrag
        End If

    End Sub

    '
    ' Zoom In button event handler
    '
    Private Sub zoomInPB_CheckedChanged(ByVal sender As Object, ByVal e As EventArgs) _
        Handles zoomInPB.CheckedChanged

        If sender.Checked Then
            winChartViewer1.MouseUsage = WinChartMouseUsage.ZoomIn
        End If

    End Sub

    '
    ' Zoom Out button event handler
    '
    Private Sub zoomOutPB_CheckedChanged(ByVal sender As Object, ByVal e As EventArgs) _
        Handles zoomOutPB.CheckedChanged

        If sender.Checked Then
            winChartViewer1.MouseUsage = WinChartMouseUsage.ZoomOut
        End If

    End Sub

    '
    ' The viewport changed event handler. In this example, we update the other controls
    ' (the scroll bar) in addition to the chart.
    '
    Private Sub winChartViewer1_ViewPortChanged(ByVal sender As Object,
        ByVal e As WinViewPortEventArgs) Handles winChartViewer1.ViewPortChanged

        updateControls(winChartViewer1)

        ' Update the chart if necessary
        If e.NeedUpdateChart Then
            drawChart(winChartViewer1)
        End If

    End Sub

    '
    ' Update controls when the view port changed
    '
    Private Sub updateControls(ByVal viewer As WinChartViewer)

        ' Update the scroll bar to reflect the view port position and width of the view port.
        hScrollBar1.Enabled = viewer.ViewPortWidth < 1
        hScrollBar1.LargeChange = Math.Ceiling(viewer.ViewPortWidth *
            (hScrollBar1.Maximum - hScrollBar1.Minimum))
        hScrollBar1.SmallChange = Math.Ceiling(hScrollBar1.LargeChange * 0.1)
        hScrollBar1.Value = Math.Round(viewer.ViewPortLeft *
            (hScrollBar1.Maximum - hScrollBar1.Minimum)) + hScrollBar1.Minimum

    End Sub

    '
    ' The scroll bar event handler
    '
    Private Sub hScrollBar1_ValueChanged(ByVal sender As Object, ByVal e As EventArgs) _
        Handles hScrollBar1.ValueChanged

        ' When the view port is changed (user drags on the chart to scroll), the scroll bar will get
        ' updated. When the scroll bar changes (eg. user drags on the scroll bar), the view port will
        ' get updated. This creates an infinite loop. To avoid this, the scroll bar can update the 
        ' view port only if the view port is not updating the scroll bar.
        If hasFinishedInitialization And Not winChartViewer1.IsInViewPortChangedEvent Then
            ' Set the view port based on the scroll bar
            winChartViewer1.ViewPortLeft = (hScrollBar1.Value - hScrollBar1.Minimum) /
                (hScrollBar1.Maximum - hScrollBar1.Minimum)

            ' Trigger a view port changed event to update the chart
            winChartViewer1.updateViewPort(True, False)
        End If

    End Sub

    '
    ' Draw track cursor when mouse is moving over plotarea
    '
    Private Sub winChartViewer1_MouseMovePlotArea(ByVal sender As Object,
        ByVal e As System.Windows.Forms.MouseEventArgs) Handles winChartViewer1.MouseMovePlotArea

        Dim viewer As WinChartViewer = sender
        trackfinance(viewer.Chart, viewer.PlotAreaMouseX)
        viewer.updateDisplay()

    End Sub

    '
    ' Draw finance chart track line with legend
    '
    Private Sub trackFinance(m As MultiChart, mouseX As Integer)

        ' Clear the current dynamic layer and get the DrawArea object to draw on it.
        Dim d As DrawArea = m.initDynamicLayer()

        ' It is possible for a FinanceChart to be empty, so we need to check for it.
        If m.getChartCount() = 0 Then
            Return
        End If

        ' Get the data x-value that is nearest to the mouse
        Dim xValue As Integer = Int(CType(m.getChart(0), XYChart).getNearestXValue(mouseX))

        ' Iterate the XY charts (main price chart and indicator charts) in the FinanceChart
        Dim c As XYChart = Nothing
        For i As Integer = 0 To m.getChartCount() - 1
            c = CType(m.getChart(i), XYChart)

            ' Variables to hold the legend entries
            Dim ohlcLegend As String = ""
            Dim legendEntries As ArrayList = New ArrayList()

            ' Iterate through all layers to find the highest data point
            For j As Integer = 0 To c.getLayerCount() - 1
                Dim layer As Layer = c.getLayerByZ(j)
                Dim xIndex As Integer = layer.getXIndexOf(xValue)
                Dim dataSetCount As Integer = layer.getDataSetCount()

                ' In a FinanceChart, only layers showing OHLC data can have 4 data sets
                If dataSetCount = 4 Then
                    Dim highValue As Double = layer.getDataSet(0).getValue(xIndex)
                    Dim lowValue As Double = layer.getDataSet(1).getValue(xIndex)
                    Dim openValue As Double = layer.getDataSet(2).getValue(xIndex)
                    Dim closeValue As Double = layer.getDataSet(3).getValue(xIndex)

                    If closeValue <> Chart.NoValue Then
                        ' Build the OHLC legend
                        ohlcLegend = "Open: " & c.formatValue(openValue, "{value|P4}") & ", High: " &
                            c.formatValue(highValue, "{value|P4}") & ", Low: " & c.formatValue(lowValue,
                            "{value|P4}") & ", Close: " & c.formatValue(closeValue, "{value|P4}")

                        ' We also draw an upward or downward triangle for up and down days and the % change
                        Dim lastCloseValue As Double = layer.getDataSet(3).getValue(xIndex - 1)
                        If lastCloseValue <> Chart.NoValue Then
                            Dim change As Double = closeValue - lastCloseValue
                            Dim percent As Double = change * 100 / closeValue
                            Dim symbol As String = IIf(change >= 0,
                                "<*font,color=008800*><*img=@triangle,width=8,color=008800*>",
                                "<*font,color=CC0000*><*img=@invertedtriangle,width=8,color=CC0000*>")

                            ohlcLegend = ohlcLegend & "  " & symbol & " " & c.formatValue(change,
                                "{value|P4}") & " (" & c.formatValue(percent, "{value|2}") & "%)<*/font*>"
                        End If

                        ' Use a <*block*> to make sure the line does not wrap within the legend entry
                        ohlcLegend = "<*block*>" & ohlcLegend & "      <*/*>"
                    End If
                Else
                    ' Iterate through all the data sets in the layer
                    For k As Integer = 0 To layer.getDataSetCount() - 1
                        Dim dataSet As ChartDirector.DataSet = layer.getDataSetByZ(k)

                        Dim name As String = dataSet.getDataName()
                        Dim value As Double = dataSet.getValue(xIndex)
                        If (Not String.IsNullOrEmpty(name)) AndAlso (value <> Chart.NoValue) Then

                            ' In a FinanceChart, the data set name consists of the indicator name and its
                            ' latest value. It is like "Vol: 123M" or "RSI (14): 55.34". As we are generating
                            ' the values dynamically, we need to extract the indictor name out, and also the
                            ' volume unit (if any).

                            ' The unit character, if any, is the last character and must not be a digit.
                            Dim unitChar As String = name.Substring(name.Length - 1)
                            If (unitChar.CompareTo("0") >= 0) AndAlso (unitChar.CompareTo("9") <= 0) Then
                                unitChar = ""
                            End If

                            ' The indicator name is the part of the name up to the colon character.
                            Dim delimiterPosition As Integer = name.IndexOf(":")
                            If delimiterPosition <> -1 Then
                                name = name.Substring(0, delimiterPosition)
                            End If

                            ' In a FinanceChart, if there are two data sets, it must be representing a range.
                            If dataSetCount = 2 Then
                                ' We show both values in the range in a single legend entry
                                value = layer.getDataSet(0).getValue(xIndex)
                                Dim value2 As Double = layer.getDataSet(1).getValue(xIndex)
                                name = name & ": " & c.formatValue(Math.Min(value, value2), "{value|P3}") &
                                    " - " & c.formatValue(Math.Max(value, value2), "{value|P3}")
                            Else
                                ' In a FinanceChart, only the layer for volume bars has 3 data sets for
                                ' up/down/flat days
                                If dataSetCount = 3 Then
                                    ' The actual volume is the sum of the 3 data sets.
                                    value = layer.getDataSet(0).getValue(xIndex) + layer.getDataSet(1
                                        ).getValue(xIndex) + layer.getDataSet(2).getValue(xIndex)
                                End If

                                ' Create the legend entry
                                name = name & ": " & c.formatValue(value, "{value|P3}") & unitChar
                            End If

                            ' Build the legend entry, consist of a colored square box and the name (with the
                            ' data value in it).
                            legendEntries.Add("<*block*><*img=@square,width=8,edgeColor=000000,color=" &
                                Hex(dataSet.getDataColor()) & "*> " & name & "<*/*>")
                        End If
                    Next
                End If
            Next

            ' Get the plot area position relative to the entire FinanceChart
            Dim plotArea As PlotArea = c.getPlotArea()
            Dim plotAreaLeftX As Integer = plotArea.getLeftX() + c.getAbsOffsetX()
            Dim plotAreaTopY As Integer = plotArea.getTopY() + c.getAbsOffsetY()

            ' The legend is formed by concatenating the legend entries.
            legendEntries.Reverse()
            Dim legendText As String = Join(CType(legendEntries.ToArray(GetType(String)), String()),
                "      ")

            ' Add the date and the ohlcLegend (if any) at the beginning of the legend
            legendText = "<*block,valign=top,maxWidth=" & (plotArea.getWidth() - 5) &
                "*><*font=Arial Bold*>[" & c.xAxis().getFormattedLabel(xValue, "mmm dd, yyyy") &
                "]<*/font*>      " & ohlcLegend & legendText

            ' Draw a vertical track line at the x-position
            d.vline(plotAreaTopY, plotAreaTopY + plotArea.getHeight(), c.getXCoor(xValue) + c.getAbsOffsetX(
                ), d.dashLineColor(&H0, &H101))

            ' Display the legend on the top of the plot area
            Dim t As TTFText = d.text(legendText, "Arial", 8)
            t.draw(plotAreaLeftX + 5, plotAreaTopY + 3, &H0, Chart.TopLeft)
        Next

    End Sub

End Class