Imports System
Imports Microsoft.VisualBasic
Imports ChartDirector

Public Class surfacecolor
    Implements DemoModule

    'Name of demo module
    Public Function getName() As String Implements DemoModule.getName
        Return "Surface Color Scale"
    End Function

    'Number of charts produced in this demo module
    Public Function getNoOfCharts() As Integer Implements DemoModule.getNoOfCharts
        Return 4
    End Function

    'Main code for creating charts
    Public Sub createChart(viewer As WinChartViewer, chartIndex As Integer) _
        Implements DemoModule.createChart

        ' The x and y coordinates of the grid
        Dim dataX() As Double = {-4, -3, -2, -1, 0, 1, 2, 3, 4}
        Dim dataY() As Double = {-4, -3, -2, -1, 0, 1, 2, 3, 4}

        ' Use random numbers for the z values on the XY grid
        Dim r As RanSeries = New RanSeries(99)
        Dim dataZ() As Double = r.get2DSeries(UBound(dataX) + 1, UBound(dataY) + 1, -0.9, 0.9)

        ' Create a SurfaceChart object of size 460 x 460 pixels with white (0xffffff) background and
        ' grey (0x888888) border
        Dim c As SurfaceChart = New SurfaceChart(460, 460, &Hffffff, &H888888)

        ' Set the surface data
        c.setData(dataX, dataY, dataZ)

        ' Add a color axis (the legend) in at the top center of the chart, with labels at the
        ' bottom. Set the axis to flat style.
        Dim cAxis As ColorAxis = c.setColorAxis(c.getWidth() \ 2, 15, Chart.Top, 250, Chart.Bottom)
        cAxis.setTitle("Color Axis")
        cAxis.setAxisBorder(Chart.Transparent, 0)

        ' By default, the color axis is synchronized with the z-axis. The following code remove the
        ' synchronization so that the color axis will auto-scale independently. Set the auto-scale
        ' minimum tick spacing to 20 pixels.
        cAxis.syncAxis(Nothing)
        cAxis.setTickDensity(20)

        If chartIndex = 1 Then
            ' Speicify a color gradient as a list of colors, and use it in the color axis.
            Dim colorGradient() As Integer = {&H0044cc, &Hffffff, &H00aa00}
            cAxis.setColorGradient(False, colorGradient)
        ElseIf chartIndex = 2 Then
            ' Specify the color scale to use in the color axis
            Dim colorScale() As Double = {-1.0, &H1a9850, -0.75, &H66bd63, -0.5, &Ha6d96a, -0.25, _
                &Hd9ef8b, 0, &Hfee08b, 0.25, &Hfdae61, 0.5, &Hf46d43, 0.75, &Hd73027, 1}
            cAxis.setColorScale(colorScale)
        ElseIf chartIndex = 3 Then
            ' Specify the color scale to use in the color axis. Also specify an underflow color
            ' 0x66ccff (blue) for regions that fall below the lower axis limit.
            Dim colorScale() As Double = {0, &Hffff99, 0.2, &H80cdc1, 0.4, &H35978f, 0.6, _
                &H01665e, 0.8, &H003c30, 1}
            cAxis.setColorScale(colorScale, &H66ccff)
        End If

        ' Set the center of the plot region at (230, 250), and set width x depth x height to 240 x
        ' 240 x 170 pixels
        c.setPlotRegion(230, 250, 240, 240, 170)

        ' Set the plot region wall thichness to 3 pixels
        c.setWallThickness(3)

        ' Set the elevation and rotation angles to 45 degrees
        c.setViewAngle(45, 45)

        ' Set the perspective level to 20
        c.setPerspective(20)

        ' Spline interpolate data to a 50 x 50 grid for a smooth surface
        c.setInterpolation(50, 50)

        ' Set the axis title
        c.xAxis().setTitle("X-Axis", "Arial Bold", 10)
        c.yAxis().setTitle("Y-Axis", "Arial Bold", 10)
        c.zAxis().setTitle("Z Axis", "Arial Bold", 10)

        ' Output the chart
        viewer.Chart = c

        'include tool tip for the chart
        viewer.ImageMap = c.getHTMLImageMap("clickable", "", _
            "title='<*cdml*>X: {x|2}<*br*>Y: {y|2}<*br*>Z: {z|2}'")

    End Sub

End Class

