Imports System
Imports Microsoft.VisualBasic
Imports ChartDirector

Public Class treemapcolors
    Implements DemoModule

    'Name of demo module
    Public Function getName() As String Implements DemoModule.getName
        Return "Tree Map Colors"
    End Function

    'Number of charts produced in this demo module
    Public Function getNoOfCharts() As Integer Implements DemoModule.getNoOfCharts
        Return 1
    End Function

    'Main code for creating chart.
    'Note: the argument chartIndex is unused because this demo only has 1 chart.
    Public Sub createChart(viewer As WinChartViewer, chartIndex As Integer) _
        Implements DemoModule.createChart

        ' The first level nodes of the tree map. There are 3 nodes.
        Dim allRegions() As String = {"Alpha", "Beta", "Gamma"}

        ' Each first level node branches to become 7 second level nodes.
        Dim energy_types() As String = {"Coal", "Oil", "Gas", "Nuclear", "Hydro", "Solar", "Wind"}

        ' Colors for the second level nodes.
        Dim colors() As Integer = {&H222222, &H666666, &H884488, &Hcc0000, &H3366cc, &H33cc33, _
            &H77bbff}

        ' The data for the 3 groups of second level nodes
        Dim region0() As Double = {0, 50, 70, 0, 60, 120, 140}
        Dim region1() As Double = {200, 50, 30, 65, 60, 40, 40}
        Dim region2() As Double = {0, 100, 70, 100, 60, 35, 40}

        ' Create a Tree Map object of size 600 x 520 pixels
        Dim c As TreeMapChart = New TreeMapChart(600, 520)

        ' Add a title to the chart
        c.addTitle("Energy Usage by Region", "Arial Bold Italic", 18)

        ' Set the plotarea at (10, 35) and of size 480 x 480 pixels
        c.setPlotArea(10, 35, 480, 480)

        ' Obtain the root of the tree map, which is the entire plot area
        Dim root As TreeMapNode = c.getRootNode()

        ' Add first level nodes to the root. We do not need to provide data as they will be computed
        ' as the sum of the second level nodes.
        root.setData(Nothing, allRegions)

        ' Add second level nodes to each of the first level node
        root.getNode(0).setData(region0, energy_types, colors)
        root.getNode(1).setData(region1, energy_types, colors)
        root.getNode(2).setData(region2, energy_types, colors)

        ' Get the prototype (template) for the first level nodes.
        Dim nodeConfig As TreeMapNode = c.getLevelPrototype(1)

        ' Set the label format for the nodes to show the label with 8pt Arial Bold font in
        ' semi-transparent black color (0x77000000). Put the text at the top left corner of the
        ' cell.
        nodeConfig.setLabelFormat("{label}", "Arial Bold", 18, &H77ffffff, Chart.TopLeft)

        ' Set the border color to white (ffffff). Use 2 pixel thick flat border style.
        nodeConfig.setColors(-1, &Hffffff, Chart.flatBorder(2))

        ' Get the prototype (template) for the second level nodes.
        Dim nodeConfig2 As TreeMapNode = c.getLevelPrototype(2)

        ' Set the label format for the nodes to show the label and value with 8pt Arial Bold font.
        ' Put the text at the center of the cell.
        nodeConfig2.setLabelFormat("{label}<*br*>{value}MW", "Arial Bold", 8, &Hffffff, _
            Chart.Center)

        ' Set the border color to white (ffffff)
        nodeConfig2.setColors(-1, &Hffffff)

        ' Add a legend box at (500, 35) with 12pt Arial font and transparent background and border.
        Dim b As LegendBox = c.addLegend(500, 35, True, "Arial", 12)
        b.setBackground(Chart.Transparent, Chart.Transparent)

        ' Add the legend keys for the colors
        For i As Integer = 0 To UBound(energy_types)
            b.addKey(energy_types(i), colors(i))
        Next

        ' Output the chart
        viewer.Chart = c

        'include tool tip for the chart
        viewer.ImageMap = c.getHTMLImageMap("clickable", "", _
            "title='<*cdml*>[{parent.label}] {label}: {value}MW'")

    End Sub

End Class

