Imports System
Imports Microsoft.VisualBasic
Imports ChartDirector

Public Class wafermap
    Implements DemoModule

    'Name of demo module
    Public Function getName() As String Implements DemoModule.getName
        Return "Wafer Map"
    End Function

    'Number of charts produced in this demo module
    Public Function getNoOfCharts() As Integer Implements DemoModule.getNoOfCharts
        Return 1
    End Function

    'Main code for creating chart.
    'Note: the argument chartIndex is unused because this demo only has 1 chart.
    Public Sub createChart(viewer As WinChartViewer, chartIndex As Integer) _
        Implements DemoModule.createChart

        ' The diameter of the wafer
        Dim diameter As Integer = 20
        Dim radius As Double = diameter / 2.0

        ' The random data array are for a square grid of 20 x 20 cells
        Dim r As RanSeries = New RanSeries(2)
        Dim zData() As Double = r.get2DSeries(diameter, diameter, 0, 100)

        ' We remove cells that are outside the wafer circle by setting them to NoValue
        For i As Integer = 0 To UBound(zData)
            Dim x As Double = i Mod diameter + 0.5
            Dim y As Double = (i - x) / diameter + 0.5
            If (x - radius) * (x - radius) + (y - radius) * (y - radius) > radius * radius Then
                zData(i) = Chart.NoValue
            End If
        Next

        ' Create an XYChart object of size 520 x 480 pixels.
        Dim c As XYChart = New XYChart(520, 480)

        ' Add a title the chart with 15pt Arial Bold font
        c.addTitle("Wafer Map Demonstration", "Arial Bold", 15)

        ' Set the plotarea at (50, 40) and of size 400 x 400 pixels. Set the backgound and border to
        ' transparent. Set both horizontal and vertical grid lines to light grey. (0xdddddd)
        Dim p As PlotArea = c.setPlotArea(50, 40, 400, 400, -1, -1, Chart.Transparent, &Hdddddd, _
            &Hdddddd)

        ' Create a discrete heat map with 20 x 20 cells
        Dim layer As DiscreteHeatMapLayer = c.addDiscreteHeatMapLayer(zData, diameter)

        ' Set the x-axis scale. Use 8pt Arial Bold font. Set axis color to transparent, so only the
        ' labels visible. Set 0.5 offset to position the labels in between the grid lines.
        c.xAxis().setLinearScale(0, diameter, 1)
        c.xAxis().setLabelStyle("Arial Bold", 8)
        c.xAxis().setColors(Chart.Transparent, Chart.TextColor)
        c.xAxis().setLabelOffset(0.5)

        ' Set the y-axis scale. Use 8pt Arial Bold font. Set axis color to transparent, so only the
        ' labels visible. Set 0.5 offset to position the labels in between the grid lines.
        c.yAxis().setLinearScale(0, diameter, 1)
        c.yAxis().setLabelStyle("Arial Bold", 8)
        c.yAxis().setColors(Chart.Transparent, Chart.TextColor)
        c.yAxis().setLabelOffset(0.5)

        ' Position the color axis 20 pixels to the right of the plot area and of the same height as
        ' the plot area. Put the labels on the right side of the color axis. Use 8pt Arial Bold font
        ' for the labels.
        Dim cAxis As ColorAxis = layer.setColorAxis(p.getRightX() + 20, p.getTopY(), _
            Chart.TopLeft, p.getHeight(), Chart.Right)
        cAxis.setLabelStyle("Arial Bold", 8)

        ' Output the chart
        viewer.Chart = c

        'include tool tip for the chart
        viewer.ImageMap = c.getHTMLImageMap("clickable", "", _
            "title='<*cdml*>({xLabel}, {yLabel}) = {z|2}'")

    End Sub

End Class

